# Generated by roxygen2: do not edit by hand

export(check_args_sdsu)
export(check_args_tlfb)
export(check_assign_na)
export(check_col_names)
export(combine_checkboxes)
export(combine_cols)
export(combine_levels)
export(compute_ab_g_dyn__cohort_edu__cgs)
export(compute_ab_g_dyn__cohort_income__hhold__3lvl)
export(compute_ab_g_dyn__cohort_income__hhold__6lvl)
export(compute_ab_g_dyn__cohort_prtnrshp__employ)
export(compute_ab_g_dyn_all)
export(compute_ab_g_stc__cohort_ethn)
export(compute_ab_g_stc__cohort_ethnrace__leg)
export(compute_ab_g_stc__cohort_ethnrace__mblack)
export(compute_ab_g_stc__cohort_ethnrace__meim)
export(compute_ab_g_stc__cohort_ethnrace__mhisp)
export(compute_ab_g_stc__cohort_race__nih)
export(compute_ab_g_stc_all)
export(compute_ab_p_demo__ntvam_all)
export(compute_ab_p_demo__ntvam_mean)
export(compute_age)
export(compute_famhx_endorsement)
export(compute_fc_p_fes__cohes_mean)
export(compute_fc_p_fes__cohes_nm)
export(compute_fc_p_fes__confl_mean)
export(compute_fc_p_fes__confl_nm)
export(compute_fc_p_fes__expr_mean)
export(compute_fc_p_fes__expr_nm)
export(compute_fc_p_fes__intelcult_mean)
export(compute_fc_p_fes__intelcult_nm)
export(compute_fc_p_fes__org_mean)
export(compute_fc_p_fes__org_nm)
export(compute_fc_p_fes__rec_mean)
export(compute_fc_p_fes__rec_nm)
export(compute_fc_p_fes_all)
export(compute_fc_p_meim__commattach_mean)
export(compute_fc_p_meim__commattach_nm)
export(compute_fc_p_meim__explor_mean)
export(compute_fc_p_meim__explor_nm)
export(compute_fc_p_meim_all)
export(compute_fc_p_meim_mean)
export(compute_fc_p_meim_nm)
export(compute_fc_p_nce__cc_mean)
export(compute_fc_p_nce__cc_nm)
export(compute_fc_p_nce__isc_mean)
export(compute_fc_p_nce__isc_nm)
export(compute_fc_p_nce_all)
export(compute_fc_p_nce_mean)
export(compute_fc_p_nce_nm)
export(compute_fc_p_nsc__ns_mean)
export(compute_fc_p_nsc__ns_nm)
export(compute_fc_p_nsc_all)
export(compute_fc_p_pk__knowl_mean)
export(compute_fc_p_pk__knowl_nm)
export(compute_fc_p_pk_all)
export(compute_fc_p_psb_all)
export(compute_fc_p_psb_mean)
export(compute_fc_p_psb_nm)
export(compute_fc_p_vs__famil_mean)
export(compute_fc_p_vs__famil_mean__v01)
export(compute_fc_p_vs__famil_nm)
export(compute_fc_p_vs__famil_nm__v01)
export(compute_fc_p_vs__indselfrel_mean)
export(compute_fc_p_vs__indselfrel_nm)
export(compute_fc_p_vs__obl_mean)
export(compute_fc_p_vs__obl_nm)
export(compute_fc_p_vs__ref_mean)
export(compute_fc_p_vs__ref_nm)
export(compute_fc_p_vs__relig_mean)
export(compute_fc_p_vs__relig_nm)
export(compute_fc_p_vs__supp_mean)
export(compute_fc_p_vs__supp_nm)
export(compute_fc_p_vs_all)
export(compute_fc_y_as__safe_mean)
export(compute_fc_y_as__safe_nm)
export(compute_fc_y_as_all)
export(compute_fc_y_crpbi__cg1_mean)
export(compute_fc_y_crpbi__cg1_nm)
export(compute_fc_y_crpbi__cg2_mean)
export(compute_fc_y_crpbi__cg2_nm)
export(compute_fc_y_crpbi_all)
export(compute_fc_y_eut__ethn_mean)
export(compute_fc_y_eut__ethn_nm)
export(compute_fc_y_eut_all)
export(compute_fc_y_fes__cohes_mean)
export(compute_fc_y_fes__cohes_nm)
export(compute_fc_y_fes__confl_mean)
export(compute_fc_y_fes__confl_nm)
export(compute_fc_y_fes_all)
export(compute_fc_y_lone_all)
export(compute_fc_y_lone_mean)
export(compute_fc_y_lone_nm)
export(compute_fc_y_meim__commattach_mean)
export(compute_fc_y_meim__commattach_nm)
export(compute_fc_y_meim__explor_mean)
export(compute_fc_y_meim__explor_nm)
export(compute_fc_y_meim_all)
export(compute_fc_y_meim_mean)
export(compute_fc_y_meim_nm)
export(compute_fc_y_mnbs__edusupp_mean)
export(compute_fc_y_mnbs__edusupp_nm)
export(compute_fc_y_mnbs__superv_mean)
export(compute_fc_y_mnbs__superv_nm)
export(compute_fc_y_mnbs_all)
export(compute_fc_y_mnbs_mean)
export(compute_fc_y_mnbs_nm)
export(compute_fc_y_naa_all)
export(compute_fc_y_naa_mean)
export(compute_fc_y_pm_all)
export(compute_fc_y_pm_mean)
export(compute_fc_y_pm_nm)
export(compute_fc_y_pnh_all)
export(compute_fc_y_pnh_nm)
export(compute_fc_y_pnh_sum)
export(compute_fc_y_psb_all)
export(compute_fc_y_psb_mean)
export(compute_fc_y_psb_nm)
export(compute_fc_y_rpi_all)
export(compute_fc_y_rpi_mean)
export(compute_fc_y_rpi_nm)
export(compute_fc_y_srpf__dis_mean)
export(compute_fc_y_srpf__dis_nm)
export(compute_fc_y_srpf__env_mean)
export(compute_fc_y_srpf__env_nm)
export(compute_fc_y_srpf__involv_mean)
export(compute_fc_y_srpf__involv_nm)
export(compute_fc_y_srpf_all)
export(compute_fc_y_vs__famil_mean)
export(compute_fc_y_vs__famil_mean__v01)
export(compute_fc_y_vs__famil_nm)
export(compute_fc_y_vs__famil_nm__v01)
export(compute_fc_y_vs__indselfrel_mean)
export(compute_fc_y_vs__indselfrel_nm)
export(compute_fc_y_vs__obl_mean)
export(compute_fc_y_vs__obl_nm)
export(compute_fc_y_vs__ref_mean)
export(compute_fc_y_vs__ref_nm)
export(compute_fc_y_vs__relig_mean)
export(compute_fc_y_vs__relig_nm)
export(compute_fc_y_vs__supp_mean)
export(compute_fc_y_vs__supp_nm)
export(compute_fc_y_vs_all)
export(compute_fc_y_wpss_all)
export(compute_fc_y_wpss_mean)
export(compute_fc_y_wpss_nm)
export(compute_fitbit_activity_table)
export(compute_fitbit_activity_table_ext)
export(compute_fitbit_activity_week)
export(compute_fitbit_sleep_table)
export(compute_fitbit_sleep_table_ext)
export(compute_fitbit_sleep_week)
export(compute_fitbit_weekly_summary)
export(compute_mh_p_abcl__afs__frnd_nm)
export(compute_mh_p_abcl__afs__frnd_sum)
export(compute_mh_p_abcl__afs__frnd_tscore)
export(compute_mh_p_abcl__cg2_sex)
export(compute_mh_p_abcl__critic_nm)
export(compute_mh_p_abcl__critic_sum)
export(compute_mh_p_abcl__critic_tscore)
export(compute_mh_p_abcl__dsm__adhd_nm)
export(compute_mh_p_abcl__dsm__adhd_sum)
export(compute_mh_p_abcl__dsm__adhd_tscore)
export(compute_mh_p_abcl__dsm__antsoc_nm)
export(compute_mh_p_abcl__dsm__antsoc_sum)
export(compute_mh_p_abcl__dsm__antsoc_tscore)
export(compute_mh_p_abcl__dsm__anx_nm)
export(compute_mh_p_abcl__dsm__anx_sum)
export(compute_mh_p_abcl__dsm__anx_tscore)
export(compute_mh_p_abcl__dsm__avoid_nm)
export(compute_mh_p_abcl__dsm__avoid_sum)
export(compute_mh_p_abcl__dsm__avoid_tscore)
export(compute_mh_p_abcl__dsm__dep_nm)
export(compute_mh_p_abcl__dsm__dep_sum)
export(compute_mh_p_abcl__dsm__dep_tscore)
export(compute_mh_p_abcl__dsm__somat_nm)
export(compute_mh_p_abcl__dsm__somat_sum)
export(compute_mh_p_abcl__dsm__somat_tscore)
export(compute_mh_p_abcl__su__drg_nm)
export(compute_mh_p_abcl__su__drg_sum)
export(compute_mh_p_abcl__su__drg_tscore)
export(compute_mh_p_abcl__su__drunk_nm)
export(compute_mh_p_abcl__su__drunk_sum)
export(compute_mh_p_abcl__su__drunk_tscore)
export(compute_mh_p_abcl__su__nic_nm)
export(compute_mh_p_abcl__su__nic_sum)
export(compute_mh_p_abcl__su__nic_tscore)
export(compute_mh_p_abcl__su_nm)
export(compute_mh_p_abcl__su_sum)
export(compute_mh_p_abcl__su_tscore)
export(compute_mh_p_abcl__synd__aggr_nm)
export(compute_mh_p_abcl__synd__aggr_sum)
export(compute_mh_p_abcl__synd__aggr_tscore)
export(compute_mh_p_abcl__synd__anxdep_nm)
export(compute_mh_p_abcl__synd__anxdep_sum)
export(compute_mh_p_abcl__synd__anxdep_tscore)
export(compute_mh_p_abcl__synd__attn_nm)
export(compute_mh_p_abcl__synd__attn_sum)
export(compute_mh_p_abcl__synd__attn_tscore)
export(compute_mh_p_abcl__synd__ext_nm)
export(compute_mh_p_abcl__synd__ext_sum)
export(compute_mh_p_abcl__synd__ext_tscore)
export(compute_mh_p_abcl__synd__int_nm)
export(compute_mh_p_abcl__synd__int_sum)
export(compute_mh_p_abcl__synd__int_tscore)
export(compute_mh_p_abcl__synd__intru_nm)
export(compute_mh_p_abcl__synd__intru_sum)
export(compute_mh_p_abcl__synd__intru_tscore)
export(compute_mh_p_abcl__synd__othpr_nm)
export(compute_mh_p_abcl__synd__othpr_sum)
export(compute_mh_p_abcl__synd__rule_nm)
export(compute_mh_p_abcl__synd__rule_sum)
export(compute_mh_p_abcl__synd__rule_tscore)
export(compute_mh_p_abcl__synd__som_nm)
export(compute_mh_p_abcl__synd__som_sum)
export(compute_mh_p_abcl__synd__som_tscore)
export(compute_mh_p_abcl__synd__tho_nm)
export(compute_mh_p_abcl__synd__tho_sum)
export(compute_mh_p_abcl__synd__tho_tscore)
export(compute_mh_p_abcl__synd__wthdr_nm)
export(compute_mh_p_abcl__synd__wthdr_sum)
export(compute_mh_p_abcl__synd__wthdr_tscore)
export(compute_mh_p_abcl_all)
export(compute_mh_p_abcl_nm)
export(compute_mh_p_abcl_sum)
export(compute_mh_p_abcl_tscore)
export(compute_mh_p_asr__afs__strng_nm)
export(compute_mh_p_asr__afs__strng_sum)
export(compute_mh_p_asr__critic_nm)
export(compute_mh_p_asr__critic_sum)
export(compute_mh_p_asr__dsm__adhd__hypimp_nm)
export(compute_mh_p_asr__dsm__adhd__hypimp_sum)
export(compute_mh_p_asr__dsm__adhd__inatt_nm)
export(compute_mh_p_asr__dsm__adhd__inatt_sum)
export(compute_mh_p_asr__dsm__adhd_nm)
export(compute_mh_p_asr__dsm__adhd_sum)
export(compute_mh_p_asr__dsm__antsoc_nm)
export(compute_mh_p_asr__dsm__antsoc_sum)
export(compute_mh_p_asr__dsm__anx_nm)
export(compute_mh_p_asr__dsm__anx_sum)
export(compute_mh_p_asr__dsm__avoid_nm)
export(compute_mh_p_asr__dsm__avoid_sum)
export(compute_mh_p_asr__dsm__dep_nm)
export(compute_mh_p_asr__dsm__dep_sum)
export(compute_mh_p_asr__dsm__somat_nm)
export(compute_mh_p_asr__dsm__somat_sum)
export(compute_mh_p_asr__synd__aggr_nm)
export(compute_mh_p_asr__synd__aggr_sum)
export(compute_mh_p_asr__synd__anxdep_nm)
export(compute_mh_p_asr__synd__anxdep_sum)
export(compute_mh_p_asr__synd__attn_nm)
export(compute_mh_p_asr__synd__attn_sum)
export(compute_mh_p_asr__synd__ext_nm)
export(compute_mh_p_asr__synd__ext_sum)
export(compute_mh_p_asr__synd__int_nm)
export(compute_mh_p_asr__synd__int_sum)
export(compute_mh_p_asr__synd__intru_nm)
export(compute_mh_p_asr__synd__intru_sum)
export(compute_mh_p_asr__synd__othpr_nm)
export(compute_mh_p_asr__synd__othpr_sum)
export(compute_mh_p_asr__synd__rule_nm)
export(compute_mh_p_asr__synd__rule_sum)
export(compute_mh_p_asr__synd__som_nm)
export(compute_mh_p_asr__synd__som_sum)
export(compute_mh_p_asr__synd__tho_nm)
export(compute_mh_p_asr__synd__tho_sum)
export(compute_mh_p_asr__synd__wthdr_nm)
export(compute_mh_p_asr__synd__wthdr_sum)
export(compute_mh_p_asr_all)
export(compute_mh_p_asr_nm)
export(compute_mh_p_asr_sum)
export(compute_mh_p_cbcl__dsm__adhd_nm)
export(compute_mh_p_cbcl__dsm__adhd_sum)
export(compute_mh_p_cbcl__dsm__adhd_tscore)
export(compute_mh_p_cbcl__dsm__anx_nm)
export(compute_mh_p_cbcl__dsm__anx_sum)
export(compute_mh_p_cbcl__dsm__anx_tscore)
export(compute_mh_p_cbcl__dsm__cond_nm)
export(compute_mh_p_cbcl__dsm__cond_sum)
export(compute_mh_p_cbcl__dsm__cond_tscore)
export(compute_mh_p_cbcl__dsm__dep_nm)
export(compute_mh_p_cbcl__dsm__dep_sum)
export(compute_mh_p_cbcl__dsm__dep_tscore)
export(compute_mh_p_cbcl__dsm__opp_nm)
export(compute_mh_p_cbcl__dsm__opp_sum)
export(compute_mh_p_cbcl__dsm__opp_tscore)
export(compute_mh_p_cbcl__dsm__somat_nm)
export(compute_mh_p_cbcl__dsm__somat_sum)
export(compute_mh_p_cbcl__dsm__somat_tscore)
export(compute_mh_p_cbcl__ocd_nm)
export(compute_mh_p_cbcl__ocd_sum)
export(compute_mh_p_cbcl__ocd_tscore)
export(compute_mh_p_cbcl__sct_nm)
export(compute_mh_p_cbcl__sct_sum)
export(compute_mh_p_cbcl__sct_tscore)
export(compute_mh_p_cbcl__strs_nm)
export(compute_mh_p_cbcl__strs_sum)
export(compute_mh_p_cbcl__strs_tscore)
export(compute_mh_p_cbcl__synd__aggr_nm)
export(compute_mh_p_cbcl__synd__aggr_sum)
export(compute_mh_p_cbcl__synd__aggr_tscore)
export(compute_mh_p_cbcl__synd__anxdep_nm)
export(compute_mh_p_cbcl__synd__anxdep_sum)
export(compute_mh_p_cbcl__synd__anxdep_tscore)
export(compute_mh_p_cbcl__synd__attn_nm)
export(compute_mh_p_cbcl__synd__attn_sum)
export(compute_mh_p_cbcl__synd__attn_tscore)
export(compute_mh_p_cbcl__synd__ext_nm)
export(compute_mh_p_cbcl__synd__ext_sum)
export(compute_mh_p_cbcl__synd__ext_tscore)
export(compute_mh_p_cbcl__synd__int_nm)
export(compute_mh_p_cbcl__synd__int_sum)
export(compute_mh_p_cbcl__synd__int_tscore)
export(compute_mh_p_cbcl__synd__othpr_nm)
export(compute_mh_p_cbcl__synd__othpr_sum)
export(compute_mh_p_cbcl__synd__rule_nm)
export(compute_mh_p_cbcl__synd__rule_sum)
export(compute_mh_p_cbcl__synd__rule_tscore)
export(compute_mh_p_cbcl__synd__soc_nm)
export(compute_mh_p_cbcl__synd__soc_sum)
export(compute_mh_p_cbcl__synd__soc_tscore)
export(compute_mh_p_cbcl__synd__som_nm)
export(compute_mh_p_cbcl__synd__som_sum)
export(compute_mh_p_cbcl__synd__som_tscore)
export(compute_mh_p_cbcl__synd__tho_nm)
export(compute_mh_p_cbcl__synd__tho_sum)
export(compute_mh_p_cbcl__synd__tho_tscore)
export(compute_mh_p_cbcl__synd__wthdep_nm)
export(compute_mh_p_cbcl__synd__wthdep_sum)
export(compute_mh_p_cbcl__synd__wthdep_tscore)
export(compute_mh_p_cbcl_all)
export(compute_mh_p_cbcl_nm)
export(compute_mh_p_cbcl_sum)
export(compute_mh_p_cbcl_tscore)
export(compute_mh_p_ders__attun_mean)
export(compute_mh_p_ders__attun_nm)
export(compute_mh_p_ders__catast_mean)
export(compute_mh_p_ders__catast_nm)
export(compute_mh_p_ders__distract_mean)
export(compute_mh_p_ders__distract_nm)
export(compute_mh_p_ders__negscnd_mean)
export(compute_mh_p_ders__negscnd_nm)
export(compute_mh_p_ders_all)
export(compute_mh_p_eatq__actv_mean)
export(compute_mh_p_eatq__actv_nm)
export(compute_mh_p_eatq__affl_mean)
export(compute_mh_p_eatq__affl_nm)
export(compute_mh_p_eatq__aggr_mean)
export(compute_mh_p_eatq__aggr_nm)
export(compute_mh_p_eatq__attn_mean)
export(compute_mh_p_eatq__attn_nm)
export(compute_mh_p_eatq__depm_mean)
export(compute_mh_p_eatq__depm_nm)
export(compute_mh_p_eatq__fear_mean)
export(compute_mh_p_eatq__fear_nm)
export(compute_mh_p_eatq__frust_mean)
export(compute_mh_p_eatq__frust_nm)
export(compute_mh_p_eatq__inhib_mean)
export(compute_mh_p_eatq__inhib_nm)
export(compute_mh_p_eatq__shy_mean)
export(compute_mh_p_eatq__shy_nm)
export(compute_mh_p_eatq__ss__efcon_mean)
export(compute_mh_p_eatq__ss__efcon_nm)
export(compute_mh_p_eatq__ss__negaff_mean)
export(compute_mh_p_eatq__ss__negaff_nm)
export(compute_mh_p_eatq__ss__surg_mean)
export(compute_mh_p_eatq__ss__surg_nm)
export(compute_mh_p_eatq__surg_mean)
export(compute_mh_p_eatq__surg_nm)
export(compute_mh_p_eatq_all)
export(compute_mh_p_famhx__alc__moth__fath_indicator)
export(compute_mh_p_famhx__alc__moth__fath_score)
export(compute_mh_p_famhx__dep__moth__fath_indicator)
export(compute_mh_p_famhx__dep__moth__fath_score)
export(compute_mh_p_famhx__doc__moth__fath_indicator)
export(compute_mh_p_famhx__doc__moth__fath_score)
export(compute_mh_p_famhx__drg__moth__fath_indicator)
export(compute_mh_p_famhx__drg__moth__fath_score)
export(compute_mh_p_famhx__halluc__moth__fath_indicator)
export(compute_mh_p_famhx__halluc__moth__fath_score)
export(compute_mh_p_famhx__hosp__moth__fath_indicator)
export(compute_mh_p_famhx__hosp__moth__fath_score)
export(compute_mh_p_famhx__mania__moth__fath_indicator)
export(compute_mh_p_famhx__mania__moth__fath_score)
export(compute_mh_p_famhx__nerve__moth__fath_indicator)
export(compute_mh_p_famhx__nerve__moth__fath_score)
export(compute_mh_p_famhx__suic__moth__fath_indicator)
export(compute_mh_p_famhx__suic__moth__fath_score)
export(compute_mh_p_famhx__troub__moth__fath_indicator)
export(compute_mh_p_famhx__troub__moth__fath_score)
export(compute_mh_p_famhx_all)
export(compute_mh_p_gbi_all)
export(compute_mh_p_gbi_nm)
export(compute_mh_p_gbi_sum)
export(compute_mh_p_ksads__adhd__past__sx_mean)
export(compute_mh_p_ksads__adhd__pres__sx_mean)
export(compute_mh_p_ksads__adhd_all)
export(compute_mh_p_ksads__agor__past__sx_mean)
export(compute_mh_p_ksads__agor__pres__sx_mean)
export(compute_mh_p_ksads__agor_all)
export(compute_mh_p_ksads__asd__past__sx_mean)
export(compute_mh_p_ksads__asd__pres__sx_mean)
export(compute_mh_p_ksads__asd_all)
export(compute_mh_p_ksads__bpd__past__sx_mean)
export(compute_mh_p_ksads__bpd__pres__sx_mean)
export(compute_mh_p_ksads__bpd_all)
export(compute_mh_p_ksads__cond__past__sx_mean)
export(compute_mh_p_ksads__cond__pres__sx_mean)
export(compute_mh_p_ksads__cond_all)
export(compute_mh_p_ksads__dep__past__sx_mean)
export(compute_mh_p_ksads__dep__pres__sx_mean)
export(compute_mh_p_ksads__dep_all)
export(compute_mh_p_ksads__dmdd__sx_mean)
export(compute_mh_p_ksads__dmdd_all)
export(compute_mh_p_ksads__ed__past__sx_mean)
export(compute_mh_p_ksads__ed__pres__sx_mean)
export(compute_mh_p_ksads__ed_all)
export(compute_mh_p_ksads__gad__past__sx_mean)
export(compute_mh_p_ksads__gad__pres__sx_mean)
export(compute_mh_p_ksads__gad_all)
export(compute_mh_p_ksads__hom__past__sx_mean)
export(compute_mh_p_ksads__hom__pres__sx_mean)
export(compute_mh_p_ksads__hom_all)
export(compute_mh_p_ksads__ocd__past__sx_mean)
export(compute_mh_p_ksads__ocd__pres__sx_mean)
export(compute_mh_p_ksads__ocd_all)
export(compute_mh_p_ksads__odd__past__sx_mean)
export(compute_mh_p_ksads__odd__pres__sx_mean)
export(compute_mh_p_ksads__odd_all)
export(compute_mh_p_ksads__panic__past__sx_mean)
export(compute_mh_p_ksads__panic__pres__sx_mean)
export(compute_mh_p_ksads__panic_all)
export(compute_mh_p_ksads__phobia__past__sx_mean)
export(compute_mh_p_ksads__phobia__pres__sx_mean)
export(compute_mh_p_ksads__phobia_all)
export(compute_mh_p_ksads__psych__past__sx_mean)
export(compute_mh_p_ksads__psych__pres__sx_mean)
export(compute_mh_p_ksads__psych_all)
export(compute_mh_p_ksads__ptsd__past__sx_mean)
export(compute_mh_p_ksads__ptsd__pres__sx_mean)
export(compute_mh_p_ksads__ptsd_all)
export(compute_mh_p_ksads__sepanx__past__sx_mean)
export(compute_mh_p_ksads__sepanx__pres__sx_mean)
export(compute_mh_p_ksads__sepanx_all)
export(compute_mh_p_ksads__sleep__past__sx_mean)
export(compute_mh_p_ksads__sleep__pres__sx_mean)
export(compute_mh_p_ksads__sleep_all)
export(compute_mh_p_ksads__socanx__past__sx_mean)
export(compute_mh_p_ksads__socanx__pres__sx_mean)
export(compute_mh_p_ksads__socanx_all)
export(compute_mh_p_ksads__suic__past__sx_mean)
export(compute_mh_p_ksads__suic__pres__sx_mean)
export(compute_mh_p_ksads__suic_all)
export(compute_mh_p_ksads__tic__past__sx_mean)
export(compute_mh_p_ksads__tic__pres__sx_mean)
export(compute_mh_p_ksads__tic_all)
export(compute_mh_p_ple__exp__bad_count)
export(compute_mh_p_ple__exp__bad_count__v01)
export(compute_mh_p_ple__exp__bad_count__v02)
export(compute_mh_p_ple__exp__bad_count__v03)
export(compute_mh_p_ple__exp__bad_count__v04)
export(compute_mh_p_ple__exp__good_count)
export(compute_mh_p_ple__exp__good_count__v01)
export(compute_mh_p_ple__exp__good_count__v02)
export(compute_mh_p_ple__exp__good_count__v03)
export(compute_mh_p_ple__exp__good_count__v04)
export(compute_mh_p_ple__exp_nm)
export(compute_mh_p_ple__exp_nm__v01)
export(compute_mh_p_ple__exp_nm__v02)
export(compute_mh_p_ple__exp_nm__v03)
export(compute_mh_p_ple__exp_nm__v04)
export(compute_mh_p_ple__severity__bad_mean)
export(compute_mh_p_ple__severity__bad_mean__v01)
export(compute_mh_p_ple__severity__bad_mean__v02)
export(compute_mh_p_ple__severity__bad_mean__v03)
export(compute_mh_p_ple__severity__bad_mean__v04)
export(compute_mh_p_ple__severity__bad_sum)
export(compute_mh_p_ple__severity__bad_sum__v01)
export(compute_mh_p_ple__severity__bad_sum__v02)
export(compute_mh_p_ple__severity__bad_sum__v03)
export(compute_mh_p_ple__severity__bad_sum__v04)
export(compute_mh_p_ple__severity__good_mean)
export(compute_mh_p_ple__severity__good_mean__v01)
export(compute_mh_p_ple__severity__good_mean__v02)
export(compute_mh_p_ple__severity__good_mean__v03)
export(compute_mh_p_ple__severity__good_mean__v04)
export(compute_mh_p_ple__severity__good_sum)
export(compute_mh_p_ple__severity__good_sum__v01)
export(compute_mh_p_ple__severity__good_sum__v02)
export(compute_mh_p_ple__severity__good_sum__v03)
export(compute_mh_p_ple__severity__good_sum__v04)
export(compute_mh_p_ple__severity_mean)
export(compute_mh_p_ple__severity_mean__v01)
export(compute_mh_p_ple__severity_mean__v02)
export(compute_mh_p_ple__severity_mean__v03)
export(compute_mh_p_ple__severity_mean__v04)
export(compute_mh_p_ple__severity_nm)
export(compute_mh_p_ple__severity_nm__v01)
export(compute_mh_p_ple__severity_nm__v02)
export(compute_mh_p_ple__severity_nm__v03)
export(compute_mh_p_ple__severity_nm__v04)
export(compute_mh_p_ple__severity_sum)
export(compute_mh_p_ple__severity_sum__v01)
export(compute_mh_p_ple__severity_sum__v02)
export(compute_mh_p_ple__severity_sum__v03)
export(compute_mh_p_ple__severity_sum__v04)
export(compute_mh_p_ple_all)
export(compute_mh_p_ple_count)
export(compute_mh_p_ple_count__v01)
export(compute_mh_p_ple_count__v02)
export(compute_mh_p_ple_count__v03)
export(compute_mh_p_ple_count__v04)
export(compute_mh_p_ple_nm)
export(compute_mh_p_ple_nm__v01)
export(compute_mh_p_ple_nm__v02)
export(compute_mh_p_ple_nm__v03)
export(compute_mh_p_ple_nm__v04)
export(compute_mh_p_ssrs_all)
export(compute_mh_p_ssrs_nm)
export(compute_mh_p_ssrs_sum)
export(compute_mh_t_bpm__attn_nm)
export(compute_mh_t_bpm__attn_sum)
export(compute_mh_t_bpm__attn_tscore)
export(compute_mh_t_bpm__ext_nm)
export(compute_mh_t_bpm__ext_sum)
export(compute_mh_t_bpm__ext_tscore)
export(compute_mh_t_bpm__int_nm)
export(compute_mh_t_bpm__int_sum)
export(compute_mh_t_bpm__int_tscore)
export(compute_mh_t_bpm_all)
export(compute_mh_t_bpm_nm)
export(compute_mh_t_bpm_sum)
export(compute_mh_t_bpm_tscore)
export(compute_mh_y_bisbas__bas__dr_nm)
export(compute_mh_y_bisbas__bas__dr_sum)
export(compute_mh_y_bisbas__bas__fs_nm)
export(compute_mh_y_bisbas__bas__fs_sum)
export(compute_mh_y_bisbas__bas__rr_nm)
export(compute_mh_y_bisbas__bas__rr_nm__v01)
export(compute_mh_y_bisbas__bas__rr_sum)
export(compute_mh_y_bisbas__bas__rr_sum__v01)
export(compute_mh_y_bisbas__bis_nm)
export(compute_mh_y_bisbas__bis_nm__v01)
export(compute_mh_y_bisbas__bis_sum)
export(compute_mh_y_bisbas__bis_sum__v01)
export(compute_mh_y_bisbas_all)
export(compute_mh_y_bpm__attn_nm)
export(compute_mh_y_bpm__attn_sum)
export(compute_mh_y_bpm__attn_tscore)
export(compute_mh_y_bpm__ext_nm)
export(compute_mh_y_bpm__ext_sum)
export(compute_mh_y_bpm__ext_tscore)
export(compute_mh_y_bpm__int_nm)
export(compute_mh_y_bpm__int_sum)
export(compute_mh_y_bpm__int_tscore)
export(compute_mh_y_bpm_all)
export(compute_mh_y_bpm_nm)
export(compute_mh_y_bpm_sum)
export(compute_mh_y_bpm_tscore)
export(compute_mh_y_erq__reapp_mean)
export(compute_mh_y_erq__reapp_nm)
export(compute_mh_y_erq__suppr_mean)
export(compute_mh_y_erq__suppr_nm)
export(compute_mh_y_erq_all)
export(compute_mh_y_ksads__bpd__past__sx_mean)
export(compute_mh_y_ksads__bpd__pres__sx_mean)
export(compute_mh_y_ksads__bpd_all)
export(compute_mh_y_ksads__cond__past__sx_mean)
export(compute_mh_y_ksads__cond__pres__sx_mean)
export(compute_mh_y_ksads__cond_all)
export(compute_mh_y_ksads__dep__past__sx_mean)
export(compute_mh_y_ksads__dep__pres__sx_mean)
export(compute_mh_y_ksads__dep_all)
export(compute_mh_y_ksads__dmdd__sx_mean)
export(compute_mh_y_ksads__dmdd_all)
export(compute_mh_y_ksads__ed__past__sx_mean)
export(compute_mh_y_ksads__ed__pres__sx_mean)
export(compute_mh_y_ksads__ed_all)
export(compute_mh_y_ksads__gad__past__sx_mean)
export(compute_mh_y_ksads__gad__pres__sx_mean)
export(compute_mh_y_ksads__gad_all)
export(compute_mh_y_ksads__ocd__past__sx_mean)
export(compute_mh_y_ksads__ocd__pres__sx_mean)
export(compute_mh_y_ksads__ocd_all)
export(compute_mh_y_ksads__panic__past__sx_mean)
export(compute_mh_y_ksads__panic__pres__sx_mean)
export(compute_mh_y_ksads__panic_all)
export(compute_mh_y_ksads__ptsd__past__sx_mean)
export(compute_mh_y_ksads__ptsd__pres__sx_mean)
export(compute_mh_y_ksads__ptsd_all)
export(compute_mh_y_ksads__sleep__past__sx_mean)
export(compute_mh_y_ksads__sleep__pres__sx_mean)
export(compute_mh_y_ksads__sleep_all)
export(compute_mh_y_ksads__socanx__past__sx_mean)
export(compute_mh_y_ksads__socanx__pres__sx_mean)
export(compute_mh_y_ksads__socanx_all)
export(compute_mh_y_ksads__suic__past__sx_mean)
export(compute_mh_y_ksads__suic__pres__sx_mean)
export(compute_mh_y_ksads__suic_all)
export(compute_mh_y_pai_all)
export(compute_mh_y_pai_nm)
export(compute_mh_y_pai_sum)
export(compute_mh_y_peq__overt__agg_nm)
export(compute_mh_y_peq__overt__agg_sum)
export(compute_mh_y_peq__overt__vict_nm)
export(compute_mh_y_peq__overt__vict_sum)
export(compute_mh_y_peq__rel__agg_nm)
export(compute_mh_y_peq__rel__agg_sum)
export(compute_mh_y_peq__rel__vict_nm)
export(compute_mh_y_peq__rel__vict_sum)
export(compute_mh_y_peq__rep__agg_nm)
export(compute_mh_y_peq__rep__agg_sum)
export(compute_mh_y_peq__rep__vict_nm)
export(compute_mh_y_peq__rep__vict_sum)
export(compute_mh_y_peq_all)
export(compute_mh_y_ple__exp__bad_count)
export(compute_mh_y_ple__exp__bad_count__v01)
export(compute_mh_y_ple__exp__bad_count__v02)
export(compute_mh_y_ple__exp__bad_count__v03)
export(compute_mh_y_ple__exp__good_count)
export(compute_mh_y_ple__exp__good_count__v01)
export(compute_mh_y_ple__exp__good_count__v02)
export(compute_mh_y_ple__exp__good_count__v03)
export(compute_mh_y_ple__exp_nm)
export(compute_mh_y_ple__exp_nm__v01)
export(compute_mh_y_ple__exp_nm__v02)
export(compute_mh_y_ple__exp_nm__v03)
export(compute_mh_y_ple__severity__bad_mean)
export(compute_mh_y_ple__severity__bad_mean__v01)
export(compute_mh_y_ple__severity__bad_mean__v02)
export(compute_mh_y_ple__severity__bad_mean__v03)
export(compute_mh_y_ple__severity__bad_sum)
export(compute_mh_y_ple__severity__bad_sum__v01)
export(compute_mh_y_ple__severity__bad_sum__v02)
export(compute_mh_y_ple__severity__bad_sum__v03)
export(compute_mh_y_ple__severity__good_mean)
export(compute_mh_y_ple__severity__good_mean__v01)
export(compute_mh_y_ple__severity__good_mean__v02)
export(compute_mh_y_ple__severity__good_mean__v03)
export(compute_mh_y_ple__severity__good_sum)
export(compute_mh_y_ple__severity__good_sum__v01)
export(compute_mh_y_ple__severity__good_sum__v02)
export(compute_mh_y_ple__severity__good_sum__v03)
export(compute_mh_y_ple__severity_mean)
export(compute_mh_y_ple__severity_mean__v01)
export(compute_mh_y_ple__severity_mean__v02)
export(compute_mh_y_ple__severity_mean__v03)
export(compute_mh_y_ple__severity_nm)
export(compute_mh_y_ple__severity_nm__v01)
export(compute_mh_y_ple__severity_nm__v02)
export(compute_mh_y_ple__severity_nm__v03)
export(compute_mh_y_ple__severity_sum)
export(compute_mh_y_ple__severity_sum__v01)
export(compute_mh_y_ple__severity_sum__v02)
export(compute_mh_y_ple__severity_sum__v03)
export(compute_mh_y_ple_all)
export(compute_mh_y_ple_count)
export(compute_mh_y_ple_count__v01)
export(compute_mh_y_ple_count__v02)
export(compute_mh_y_ple_count__v03)
export(compute_mh_y_ple_nm)
export(compute_mh_y_ple_nm__v01)
export(compute_mh_y_ple_nm__v02)
export(compute_mh_y_ple_nm__v03)
export(compute_mh_y_pps__bother__no_count)
export(compute_mh_y_pps__bother__yes_count)
export(compute_mh_y_pps__bother_nm)
export(compute_mh_y_pps__dist__curr_score)
export(compute_mh_y_pps__dist__pers_score)
export(compute_mh_y_pps__severity_mean)
export(compute_mh_y_pps__severity_nm)
export(compute_mh_y_pps__severity_score)
export(compute_mh_y_pps_all)
export(compute_mh_y_pps_count)
export(compute_mh_y_pps_nm)
export(compute_mh_y_ppsss__dist__curr_count)
export(compute_mh_y_ppsss__dist__curr_ever)
export(compute_mh_y_ppsss__dist__curr_first)
export(compute_mh_y_ppsss__dist__pers_count)
export(compute_mh_y_ppsss__dist__pers_ever)
export(compute_mh_y_ppsss__dist__pers_first)
export(compute_mh_y_ppsss_all)
export(compute_mh_y_sup_all)
export(compute_mh_y_sup_nm)
export(compute_mh_y_sup_sum)
export(compute_mh_y_upps__nurg_nm)
export(compute_mh_y_upps__nurg_sum)
export(compute_mh_y_upps__pers_nm)
export(compute_mh_y_upps__pers_sum)
export(compute_mh_y_upps__plan_nm)
export(compute_mh_y_upps__plan_sum)
export(compute_mh_y_upps__purg_nm)
export(compute_mh_y_upps__purg_sum)
export(compute_mh_y_upps__sens_nm)
export(compute_mh_y_upps__sens_sum)
export(compute_mh_y_upps_all)
export(compute_mh_y_ysr__dsm__adhd_nm)
export(compute_mh_y_ysr__dsm__adhd_sum)
export(compute_mh_y_ysr__dsm__adhd_tscore)
export(compute_mh_y_ysr__dsm__anx_nm)
export(compute_mh_y_ysr__dsm__anx_sum)
export(compute_mh_y_ysr__dsm__anx_tscore)
export(compute_mh_y_ysr__dsm__cond_nm)
export(compute_mh_y_ysr__dsm__cond_sum)
export(compute_mh_y_ysr__dsm__cond_tscore)
export(compute_mh_y_ysr__dsm__dep_nm)
export(compute_mh_y_ysr__dsm__dep_sum)
export(compute_mh_y_ysr__dsm__dep_tscore)
export(compute_mh_y_ysr__dsm__opp_nm)
export(compute_mh_y_ysr__dsm__opp_sum)
export(compute_mh_y_ysr__dsm__opp_tscore)
export(compute_mh_y_ysr__dsm__somat_nm)
export(compute_mh_y_ysr__dsm__somat_sum)
export(compute_mh_y_ysr__dsm__somat_tscore)
export(compute_mh_y_ysr__pos_nm)
export(compute_mh_y_ysr__pos_sum)
export(compute_mh_y_ysr__pos_tscore)
export(compute_mh_y_ysr__synd__aggr_nm)
export(compute_mh_y_ysr__synd__aggr_sum)
export(compute_mh_y_ysr__synd__aggr_tscore)
export(compute_mh_y_ysr__synd__anxdep_nm)
export(compute_mh_y_ysr__synd__anxdep_sum)
export(compute_mh_y_ysr__synd__anxdep_tscore)
export(compute_mh_y_ysr__synd__attn_nm)
export(compute_mh_y_ysr__synd__attn_sum)
export(compute_mh_y_ysr__synd__attn_tscore)
export(compute_mh_y_ysr__synd__ext_nm)
export(compute_mh_y_ysr__synd__ext_sum)
export(compute_mh_y_ysr__synd__ext_tscore)
export(compute_mh_y_ysr__synd__int_nm)
export(compute_mh_y_ysr__synd__int_sum)
export(compute_mh_y_ysr__synd__int_tscore)
export(compute_mh_y_ysr__synd__othpr_nm)
export(compute_mh_y_ysr__synd__othpr_sum)
export(compute_mh_y_ysr__synd__rule_nm)
export(compute_mh_y_ysr__synd__rule_sum)
export(compute_mh_y_ysr__synd__rule_tscore)
export(compute_mh_y_ysr__synd__soc_nm)
export(compute_mh_y_ysr__synd__soc_sum)
export(compute_mh_y_ysr__synd__soc_tscore)
export(compute_mh_y_ysr__synd__som_nm)
export(compute_mh_y_ysr__synd__som_sum)
export(compute_mh_y_ysr__synd__som_tscore)
export(compute_mh_y_ysr__synd__tho_nm)
export(compute_mh_y_ysr__synd__tho_sum)
export(compute_mh_y_ysr__synd__tho_tscore)
export(compute_mh_y_ysr__synd__wthdep_nm)
export(compute_mh_y_ysr__synd__wthdep_sum)
export(compute_mh_y_ysr__synd__wthdep_tscore)
export(compute_mh_y_ysr_all)
export(compute_mh_y_ysr_nm)
export(compute_mh_y_ysr_sum)
export(compute_mh_y_ysr_tscore)
export(compute_nc_p_bdefs__sympt_count)
export(compute_nc_p_bdefs_all)
export(compute_nc_p_bdefs_nm)
export(compute_nc_p_bdefs_sum)
export(compute_nc_y_ehis_all)
export(compute_nc_y_ehis_nm)
export(compute_nc_y_ehis_score)
export(compute_nt_p_yst__pmum_mean)
export(compute_nt_p_yst__pmum_nm)
export(compute_nt_p_yst__screen__wkdy_nm)
export(compute_nt_p_yst__screen__wkdy_sum)
export(compute_nt_p_yst__screen__wknd_nm)
export(compute_nt_p_yst__screen__wknd_sum)
export(compute_nt_p_yst_all)
export(compute_nt_y_stq__screen__wkdy_nm)
export(compute_nt_y_stq__screen__wkdy_sum)
export(compute_nt_y_stq__screen__wknd_nm)
export(compute_nt_y_stq__screen__wknd_sum)
export(compute_nt_y_stq_all)
export(compute_ph_meds_catg_all)
export(compute_ph_meds_estuse_flags_all)
export(compute_ph_p_anthr__fath_height__cm)
export(compute_ph_p_anthr__fath_height__in)
export(compute_ph_p_anthr__moth_height__cm)
export(compute_ph_p_anthr__moth_height__in)
export(compute_ph_p_anthr_all)
export(compute_ph_p_cna_all)
export(compute_ph_p_cna_nm)
export(compute_ph_p_cna_sum)
export(compute_ph_p_dhx_birthweight)
export(compute_ph_p_dhx_catg_all)
export(compute_ph_p_meds_catg_all)
export(compute_ph_p_meds_estuse_flags_all)
export(compute_ph_p_otbi__loc__30m_count)
export(compute_ph_p_otbi__loc__30m_nm)
export(compute_ph_p_otbi__loc__tbiage_nm)
export(compute_ph_p_otbi__loc_before15)
export(compute_ph_p_otbi__loc_count)
export(compute_ph_p_otbi__loc_nm)
export(compute_ph_p_otbi__loc_tbiage)
export(compute_ph_p_otbi__rpt_count)
export(compute_ph_p_otbi__rpt_nm)
export(compute_ph_p_otbi_all)
export(compute_ph_p_otbi_nm)
export(compute_ph_p_otbi_tbiworst)
export(compute_ph_p_pds__f__categ_nm)
export(compute_ph_p_pds__f_categ)
export(compute_ph_p_pds__f_mean)
export(compute_ph_p_pds__f_nm)
export(compute_ph_p_pds__m__categ_nm)
export(compute_ph_p_pds__m_categ)
export(compute_ph_p_pds__m_mean)
export(compute_ph_p_pds__m_nm)
export(compute_ph_p_pds_all)
export(compute_ph_p_sds__da_nm)
export(compute_ph_p_sds__da_sum)
export(compute_ph_p_sds__dims_nm)
export(compute_ph_p_sds__dims_sum)
export(compute_ph_p_sds__does_nm)
export(compute_ph_p_sds__does_sum)
export(compute_ph_p_sds__hyphy_nm)
export(compute_ph_p_sds__hyphy_sum)
export(compute_ph_p_sds__sbd_nm)
export(compute_ph_p_sds__sbd_sum)
export(compute_ph_p_sds__swtd_nm)
export(compute_ph_p_sds__swtd_sum)
export(compute_ph_p_sds_all)
export(compute_ph_p_sds_nm)
export(compute_ph_p_sds_sum)
export(compute_ph_y_anthr__height_mean)
export(compute_ph_y_anthr__height_nm)
export(compute_ph_y_anthr__weight_mean)
export(compute_ph_y_anthr__weight_nm)
export(compute_ph_y_anthr_all)
export(compute_ph_y_bp__dia_mean)
export(compute_ph_y_bp__dia_nm)
export(compute_ph_y_bp__hrate_mean)
export(compute_ph_y_bp__hrate_nm)
export(compute_ph_y_bp__sys_mean)
export(compute_ph_y_bp__sys_nm)
export(compute_ph_y_bp_all)
export(compute_ph_y_mctq__fd__bed__end__24h_t)
export(compute_ph_y_mctq__fd__bed__end__36h_t)
export(compute_ph_y_mctq__fd__bed__start__24h_t)
export(compute_ph_y_mctq__fd__bed__start__36h_t)
export(compute_ph_y_mctq__fd__bed_sum)
export(compute_ph_y_mctq__fd__sleep__end__24h_t)
export(compute_ph_y_mctq__fd__sleep__end__36h_t)
export(compute_ph_y_mctq__fd__sleep__mid__24h_t)
export(compute_ph_y_mctq__fd__sleep__mid__36h_t)
export(compute_ph_y_mctq__fd__sleep__onset__24h_t)
export(compute_ph_y_mctq__fd__sleep__onset__36h_t)
export(compute_ph_y_mctq__fd__sleep__start__24h_t)
export(compute_ph_y_mctq__fd__sleep__start__36h_t)
export(compute_ph_y_mctq__fd__sleep__waso_sum)
export(compute_ph_y_mctq__fd__sleep_dur)
export(compute_ph_y_mctq__fd__sleep_inertia)
export(compute_ph_y_mctq__fd__sleep_latent)
export(compute_ph_y_mctq__fd__sleep_period)
export(compute_ph_y_mctq__fd_count)
export(compute_ph_y_mctq__raw__36h_chrono)
export(compute_ph_y_mctq__school__leave__24h_t)
export(compute_ph_y_mctq__school__leave__36h_t)
export(compute_ph_y_mctq__school__start__24h_t)
export(compute_ph_y_mctq__school__start__36h_t)
export(compute_ph_y_mctq__sd__bed__end__24h_t)
export(compute_ph_y_mctq__sd__bed__end__36h_t)
export(compute_ph_y_mctq__sd__bed__start__24h_t)
export(compute_ph_y_mctq__sd__bed__start__36h_t)
export(compute_ph_y_mctq__sd__bed_sum)
export(compute_ph_y_mctq__sd__sleep__end__24h_t)
export(compute_ph_y_mctq__sd__sleep__end__36h_t)
export(compute_ph_y_mctq__sd__sleep__mid__24h_t)
export(compute_ph_y_mctq__sd__sleep__mid__36h_t)
export(compute_ph_y_mctq__sd__sleep__onset__24h_t)
export(compute_ph_y_mctq__sd__sleep__onset__36h_t)
export(compute_ph_y_mctq__sd__sleep__start__24h_t)
export(compute_ph_y_mctq__sd__sleep__start__36h_t)
export(compute_ph_y_mctq__sd__sleep__waso_sum)
export(compute_ph_y_mctq__sd__sleep_dur)
export(compute_ph_y_mctq__sd__sleep_inertia)
export(compute_ph_y_mctq__sd__sleep_latent)
export(compute_ph_y_mctq__sd__sleep_period)
export(compute_ph_y_mctq__sd_count)
export(compute_ph_y_mctq__sleep_dur)
export(compute_ph_y_mctq__sleep_loss)
export(compute_ph_y_mctq__sleep_period)
export(compute_ph_y_mctq__socjl_absl)
export(compute_ph_y_mctq__socjl_rel)
export(compute_ph_y_mctq_all)
export(compute_ph_y_mctq_chrono)
export(compute_ph_y_mctq_outlier)
export(compute_ph_y_meds_catg_all)
export(compute_ph_y_meds_estuse_flags_all)
export(compute_ph_y_pds__f__categ_nm)
export(compute_ph_y_pds__f_categ)
export(compute_ph_y_pds__f_mean)
export(compute_ph_y_pds__f_nm)
export(compute_ph_y_pds__m__categ_nm)
export(compute_ph_y_pds__m_categ)
export(compute_ph_y_pds__m_mean)
export(compute_ph_y_pds__m_nm)
export(compute_ph_y_pds_all)
export(compute_ss_use_onset_age)
export(compute_ss_use_onset_event)
export(compute_ss_use_yn)
export(compute_su_p_ksads__aud__past__sx_mean)
export(compute_su_p_ksads__aud__pres__sx_mean)
export(compute_su_p_ksads__aud_all)
export(compute_su_p_ksads__dud__coc__past__sx_mean)
export(compute_su_p_ksads__dud__coc__pres__sx_mean)
export(compute_su_p_ksads__dud__hall__past__sx_mean)
export(compute_su_p_ksads__dud__hall__pres__sx_mean)
export(compute_su_p_ksads__dud__mj__past__sx_mean)
export(compute_su_p_ksads__dud__mj__pres__sx_mean)
export(compute_su_p_ksads__dud__nic__past__sx_mean)
export(compute_su_p_ksads__dud__nic__pres__sx_mean)
export(compute_su_p_ksads__dud__opi__past__sx_mean)
export(compute_su_p_ksads__dud__opi__pres__sx_mean)
export(compute_su_p_ksads__dud__othdrg__past__sx_mean)
export(compute_su_p_ksads__dud__othdrg__pres__sx_mean)
export(compute_su_p_ksads__dud__past__sx_mean)
export(compute_su_p_ksads__dud__pcp__past__sx_mean)
export(compute_su_p_ksads__dud__pcp__pres__sx_mean)
export(compute_su_p_ksads__dud__pres__sx_mean)
export(compute_su_p_ksads__dud__sed__past__sx_mean)
export(compute_su_p_ksads__dud__sed__pres__sx_mean)
export(compute_su_p_ksads__dud__solv__past__sx_mean)
export(compute_su_p_ksads__dud__solv__pres__sx_mean)
export(compute_su_p_ksads__dud__stim__past__sx_mean)
export(compute_su_p_ksads__dud__stim__pres__sx_mean)
export(compute_su_p_ksads__dud_all)
export(compute_su_y_alcexp__neg_nm)
export(compute_su_y_alcexp__neg_prsum)
export(compute_su_y_alcexp__pos_nm)
export(compute_su_y_alcexp__pos_prsum)
export(compute_su_y_alcexp_all)
export(compute_su_y_alchss_all)
export(compute_su_y_alchss_count)
export(compute_su_y_alchss_nm)
export(compute_su_y_alchss_sum)
export(compute_su_y_alcprob_all)
export(compute_su_y_alcprob_nm)
export(compute_su_y_alcprob_prsum)
export(compute_su_y_alcsre__6mo_count)
export(compute_su_y_alcsre__6mo_mean)
export(compute_su_y_alcsre__6mo_nm)
export(compute_su_y_alcsre__first5_count)
export(compute_su_y_alcsre__first5_mean)
export(compute_su_y_alcsre__first5_nm)
export(compute_su_y_alcsre__hvy_count)
export(compute_su_y_alcsre__hvy_mean)
export(compute_su_y_alcsre__hvy_nm)
export(compute_su_y_alcsre_all)
export(compute_su_y_caff__coffee_sum)
export(compute_su_y_caff__energy__drink_sum)
export(compute_su_y_caff__energy__shot_sum)
export(compute_su_y_caff__energy_sum)
export(compute_su_y_caff__espres_sum)
export(compute_su_y_caff__oth_sum)
export(compute_su_y_caff__soda_sum)
export(compute_su_y_caff__suppl_sum)
export(compute_su_y_caff__tea_sum)
export(compute_su_y_caff_all)
export(compute_su_y_cigexp__neg_nm)
export(compute_su_y_cigexp__neg_prsum)
export(compute_su_y_cigexp__neg_prsum__v01)
export(compute_su_y_cigexp__pos_nm)
export(compute_su_y_cigexp__pos_prsum)
export(compute_su_y_cigexp__pos_prsum__v01)
export(compute_su_y_cigexp_all)
export(compute_su_y_drgprob_all)
export(compute_su_y_drgprob_nm)
export(compute_su_y_drgprob_prsum)
export(compute_su_y_ksads__aud__past__sx_mean)
export(compute_su_y_ksads__aud__pres__sx_mean)
export(compute_su_y_ksads__aud_all)
export(compute_su_y_ksads__dud__coc__past__sx_mean)
export(compute_su_y_ksads__dud__coc__pres__sx_mean)
export(compute_su_y_ksads__dud__hall__past__sx_mean)
export(compute_su_y_ksads__dud__hall__pres__sx_mean)
export(compute_su_y_ksads__dud__mj__past__sx_mean)
export(compute_su_y_ksads__dud__mj__pres__sx_mean)
export(compute_su_y_ksads__dud__nic__past__sx_mean)
export(compute_su_y_ksads__dud__nic__pres__sx_mean)
export(compute_su_y_ksads__dud__opi__past__sx_mean)
export(compute_su_y_ksads__dud__opi__pres__sx_mean)
export(compute_su_y_ksads__dud__othdrg__past__sx_mean)
export(compute_su_y_ksads__dud__othdrg__pres__sx_mean)
export(compute_su_y_ksads__dud__past__sx_mean)
export(compute_su_y_ksads__dud__pcp__past__sx_mean)
export(compute_su_y_ksads__dud__pcp__pres__sx_mean)
export(compute_su_y_ksads__dud__pres__sx_mean)
export(compute_su_y_ksads__dud__sed__past__sx_mean)
export(compute_su_y_ksads__dud__sed__pres__sx_mean)
export(compute_su_y_ksads__dud__solv__past__sx_mean)
export(compute_su_y_ksads__dud__solv__pres__sx_mean)
export(compute_su_y_ksads__dud__stim__past__sx_mean)
export(compute_su_y_ksads__dud__stim__pres__sx_mean)
export(compute_su_y_ksads__dud_all)
export(compute_su_y_mjexp__neg_nm)
export(compute_su_y_mjexp__neg_prsum)
export(compute_su_y_mjexp__pos_nm)
export(compute_su_y_mjexp__pos_prsum)
export(compute_su_y_mjexp_all)
export(compute_su_y_mjprob_all)
export(compute_su_y_mjprob_nm)
export(compute_su_y_mjprob_prsum)
export(compute_su_y_mjsre__neg_nm)
export(compute_su_y_mjsre__neg_sum)
export(compute_su_y_mjsre__pos_nm)
export(compute_su_y_mjsre__pos_sum)
export(compute_su_y_mjsre_all)
export(compute_su_y_mjsre_nm)
export(compute_su_y_mjsre_sum)
export(compute_su_y_nicsre__chew_nm)
export(compute_su_y_nicsre__chew_sum)
export(compute_su_y_nicsre__cig_nm)
export(compute_su_y_nicsre__cig_sum)
export(compute_su_y_nicsre__vape_nm)
export(compute_su_y_nicsre__vape_sum)
export(compute_su_y_nicsre_all)
export(compute_su_y_nicvapeexp__neg_nm)
export(compute_su_y_nicvapeexp__neg_prsum)
export(compute_su_y_nicvapeexp__pos_nm)
export(compute_su_y_nicvapeexp__pos_prsum)
export(compute_su_y_nicvapeexp_all)
export(compute_su_y_sui__last__day_count)
export(compute_su_y_sui__onset_useage)
export(compute_su_y_sui__reg_useage)
export(compute_tlfb_abst)
export(compute_tlfb_dt)
export(compute_tlfb_maxdose)
export(compute_tlfb_mean)
export(compute_tlfb_totdose)
export(compute_tlfb_totdose_sum)
export(compute_tlfb_ud)
export(convert_time_mctq)
export(create_session_num)
export(filter_tlfb)
export(get_tscore_tbl)
export(insert_reference)
export(make_static)
export(map_mid_years)
export(md_bullet)
export(prepare_data_sdsu)
export(product_vars)
export(recode_levels)
export(ss_count)
export(ss_count_cond)
export(ss_max)
export(ss_mean)
export(ss_mean_mh_ple)
export(ss_mean_pos)
export(ss_nm)
export(ss_nm_mh_ple)
export(ss_prsum)
export(ss_sum)
export(ss_sum_mh_ple)
export(ss_tscore)
export(sui_substances)
export(tlfb_substances)
export(vars_ab_g_dyn__cohort_edu__cgs)
export(vars_ab_g_dyn__cohort_income__hhold__6lvl)
export(vars_ab_g_dyn__cohort_prtnrshp__employ)
export(vars_ab_g_stc__cohort_ethn)
export(vars_ab_g_stc__cohort_ethnrace__leg)
export(vars_ab_g_stc__cohort_ethnrace__mblack)
export(vars_ab_g_stc__cohort_ethnrace__meim)
export(vars_ab_g_stc__cohort_ethnrace__mhisp)
export(vars_ab_g_stc__cohort_race__nih)
export(vars_ab_p_demo__ntvam)
export(vars_fc_p_fes__cohes)
export(vars_fc_p_fes__confl)
export(vars_fc_p_fes__expr)
export(vars_fc_p_fes__intelcult)
export(vars_fc_p_fes__org)
export(vars_fc_p_fes__rec)
export(vars_fc_p_meim)
export(vars_fc_p_meim__commattach)
export(vars_fc_p_meim__explor)
export(vars_fc_p_nce)
export(vars_fc_p_nce__cc)
export(vars_fc_p_nce__isc)
export(vars_fc_p_nsc__ns)
export(vars_fc_p_pk__knowl)
export(vars_fc_p_psb)
export(vars_fc_p_vs__famil)
export(vars_fc_p_vs__famil__v01)
export(vars_fc_p_vs__indselfrel)
export(vars_fc_p_vs__obl)
export(vars_fc_p_vs__ref)
export(vars_fc_p_vs__relig)
export(vars_fc_p_vs__supp)
export(vars_fc_y_as__safe)
export(vars_fc_y_crpbi__cg1)
export(vars_fc_y_crpbi__cg2)
export(vars_fc_y_eut__ethn)
export(vars_fc_y_fes__cohes)
export(vars_fc_y_fes__confl)
export(vars_fc_y_lone)
export(vars_fc_y_meim)
export(vars_fc_y_meim__commattach)
export(vars_fc_y_meim__explor)
export(vars_fc_y_mnbs)
export(vars_fc_y_mnbs__edusupp)
export(vars_fc_y_mnbs__superv)
export(vars_fc_y_naa)
export(vars_fc_y_pm)
export(vars_fc_y_pnh)
export(vars_fc_y_psb)
export(vars_fc_y_rpi)
export(vars_fc_y_srpf__dis)
export(vars_fc_y_srpf__env)
export(vars_fc_y_srpf__involv)
export(vars_fc_y_vs__famil)
export(vars_fc_y_vs__famil__v01)
export(vars_fc_y_vs__indselfrel)
export(vars_fc_y_vs__obl)
export(vars_fc_y_vs__ref)
export(vars_fc_y_vs__relig)
export(vars_fc_y_vs__supp)
export(vars_fc_y_wpss)
export(vars_mh_p_abcl)
export(vars_mh_p_abcl__afs__frnd)
export(vars_mh_p_abcl__cg2)
export(vars_mh_p_abcl__critic)
export(vars_mh_p_abcl__dsm__adhd)
export(vars_mh_p_abcl__dsm__antsoc)
export(vars_mh_p_abcl__dsm__anx)
export(vars_mh_p_abcl__dsm__avoid)
export(vars_mh_p_abcl__dsm__dep)
export(vars_mh_p_abcl__dsm__somat)
export(vars_mh_p_abcl__su)
export(vars_mh_p_abcl__su__drg)
export(vars_mh_p_abcl__su__drunk)
export(vars_mh_p_abcl__su__nic)
export(vars_mh_p_abcl__synd__aggr)
export(vars_mh_p_abcl__synd__anxdep)
export(vars_mh_p_abcl__synd__attn)
export(vars_mh_p_abcl__synd__ext)
export(vars_mh_p_abcl__synd__int)
export(vars_mh_p_abcl__synd__intru)
export(vars_mh_p_abcl__synd__othpr)
export(vars_mh_p_abcl__synd__rule)
export(vars_mh_p_abcl__synd__som)
export(vars_mh_p_abcl__synd__tho)
export(vars_mh_p_abcl__synd__wthdr)
export(vars_mh_p_asr)
export(vars_mh_p_asr__afs__strng)
export(vars_mh_p_asr__critic)
export(vars_mh_p_asr__dsm__adhd)
export(vars_mh_p_asr__dsm__adhd__hypimp)
export(vars_mh_p_asr__dsm__adhd__inatt)
export(vars_mh_p_asr__dsm__antsoc)
export(vars_mh_p_asr__dsm__anx)
export(vars_mh_p_asr__dsm__avoid)
export(vars_mh_p_asr__dsm__dep)
export(vars_mh_p_asr__dsm__somat)
export(vars_mh_p_asr__synd__aggr)
export(vars_mh_p_asr__synd__anxdep)
export(vars_mh_p_asr__synd__attn)
export(vars_mh_p_asr__synd__ext)
export(vars_mh_p_asr__synd__int)
export(vars_mh_p_asr__synd__intru)
export(vars_mh_p_asr__synd__othpr)
export(vars_mh_p_asr__synd__rule)
export(vars_mh_p_asr__synd__som)
export(vars_mh_p_asr__synd__tho)
export(vars_mh_p_asr__synd__wthdr)
export(vars_mh_p_cbcl)
export(vars_mh_p_cbcl__dsm__adhd)
export(vars_mh_p_cbcl__dsm__anx)
export(vars_mh_p_cbcl__dsm__cond)
export(vars_mh_p_cbcl__dsm__dep)
export(vars_mh_p_cbcl__dsm__opp)
export(vars_mh_p_cbcl__dsm__somat)
export(vars_mh_p_cbcl__ocd)
export(vars_mh_p_cbcl__sct)
export(vars_mh_p_cbcl__strs)
export(vars_mh_p_cbcl__synd__aggr)
export(vars_mh_p_cbcl__synd__anxdep)
export(vars_mh_p_cbcl__synd__attn)
export(vars_mh_p_cbcl__synd__ext)
export(vars_mh_p_cbcl__synd__int)
export(vars_mh_p_cbcl__synd__othpr)
export(vars_mh_p_cbcl__synd__rule)
export(vars_mh_p_cbcl__synd__soc)
export(vars_mh_p_cbcl__synd__som)
export(vars_mh_p_cbcl__synd__tho)
export(vars_mh_p_cbcl__synd__wthdep)
export(vars_mh_p_ders__attun)
export(vars_mh_p_ders__catast)
export(vars_mh_p_ders__distract)
export(vars_mh_p_ders__negscnd)
export(vars_mh_p_eatq__actv)
export(vars_mh_p_eatq__affl)
export(vars_mh_p_eatq__aggr)
export(vars_mh_p_eatq__attn)
export(vars_mh_p_eatq__depm)
export(vars_mh_p_eatq__fear)
export(vars_mh_p_eatq__frust)
export(vars_mh_p_eatq__inhib)
export(vars_mh_p_eatq__shy)
export(vars_mh_p_eatq__surg)
export(vars_mh_p_famhx__alc__moth__fath_indicator)
export(vars_mh_p_famhx__alc__moth__fath_score)
export(vars_mh_p_famhx__dep__moth__fath_indicator)
export(vars_mh_p_famhx__dep__moth__fath_score)
export(vars_mh_p_famhx__doc__moth__fath_indicator)
export(vars_mh_p_famhx__doc__moth__fath_score)
export(vars_mh_p_famhx__drg__moth__fath_indicator)
export(vars_mh_p_famhx__drg__moth__fath_score)
export(vars_mh_p_famhx__halluc__moth__fath_indicator)
export(vars_mh_p_famhx__halluc__moth__fath_score)
export(vars_mh_p_famhx__hosp__moth__fath_indicator)
export(vars_mh_p_famhx__hosp__moth__fath_score)
export(vars_mh_p_famhx__mania__moth__fath_indicator)
export(vars_mh_p_famhx__mania__moth__fath_score)
export(vars_mh_p_famhx__nerve__moth__fath_indicator)
export(vars_mh_p_famhx__nerve__moth__fath_score)
export(vars_mh_p_famhx__suic__moth__fath_indicator)
export(vars_mh_p_famhx__suic__moth__fath_score)
export(vars_mh_p_famhx__troub__moth__fath_indicator)
export(vars_mh_p_famhx__troub__moth__fath_score)
export(vars_mh_p_gbi)
export(vars_mh_p_ksads__adhd__past__sx)
export(vars_mh_p_ksads__adhd__pres__sx)
export(vars_mh_p_ksads__agor__past__sx)
export(vars_mh_p_ksads__agor__pres__sx)
export(vars_mh_p_ksads__asd__past__sx)
export(vars_mh_p_ksads__asd__pres__sx)
export(vars_mh_p_ksads__bpd__past__sx)
export(vars_mh_p_ksads__bpd__pres__sx)
export(vars_mh_p_ksads__cond__past__sx)
export(vars_mh_p_ksads__cond__pres__sx)
export(vars_mh_p_ksads__dep__past__sx)
export(vars_mh_p_ksads__dep__pres__sx)
export(vars_mh_p_ksads__dmdd__sx)
export(vars_mh_p_ksads__ed__past__sx)
export(vars_mh_p_ksads__ed__pres__sx)
export(vars_mh_p_ksads__gad__past__sx)
export(vars_mh_p_ksads__gad__pres__sx)
export(vars_mh_p_ksads__hom__past__sx)
export(vars_mh_p_ksads__hom__pres__sx)
export(vars_mh_p_ksads__ocd__past__sx)
export(vars_mh_p_ksads__ocd__pres__sx)
export(vars_mh_p_ksads__odd__past__sx)
export(vars_mh_p_ksads__odd__pres__sx)
export(vars_mh_p_ksads__panic__past__sx)
export(vars_mh_p_ksads__panic__pres__sx)
export(vars_mh_p_ksads__phobia__past__sx)
export(vars_mh_p_ksads__phobia__pres__sx)
export(vars_mh_p_ksads__psych__past__sx)
export(vars_mh_p_ksads__psych__pres__sx)
export(vars_mh_p_ksads__ptsd__past__sx)
export(vars_mh_p_ksads__ptsd__pres__sx)
export(vars_mh_p_ksads__sepanx__past__sx)
export(vars_mh_p_ksads__sepanx__pres__sx)
export(vars_mh_p_ksads__sleep__past__sx)
export(vars_mh_p_ksads__sleep__pres__sx)
export(vars_mh_p_ksads__socanx__past__sx)
export(vars_mh_p_ksads__socanx__pres__sx)
export(vars_mh_p_ksads__suic__past__sx)
export(vars_mh_p_ksads__suic__pres__sx)
export(vars_mh_p_ksads__tic__past__sx)
export(vars_mh_p_ksads__tic__pres__sx)
export(vars_mh_p_ple)
export(vars_mh_p_ple__exp)
export(vars_mh_p_ple__exp__v01)
export(vars_mh_p_ple__exp__v02)
export(vars_mh_p_ple__exp__v03)
export(vars_mh_p_ple__exp__v04)
export(vars_mh_p_ple__severity)
export(vars_mh_p_ple__severity__v01)
export(vars_mh_p_ple__severity__v02)
export(vars_mh_p_ple__severity__v03)
export(vars_mh_p_ple__severity__v04)
export(vars_mh_p_ple__v01)
export(vars_mh_p_ple__v02)
export(vars_mh_p_ple__v03)
export(vars_mh_p_ple__v04)
export(vars_mh_p_ssrs)
export(vars_mh_t_bpm)
export(vars_mh_t_bpm__attn)
export(vars_mh_t_bpm__ext)
export(vars_mh_t_bpm__int)
export(vars_mh_y_bisbas__bas__dr)
export(vars_mh_y_bisbas__bas__fs)
export(vars_mh_y_bisbas__bas__rr)
export(vars_mh_y_bisbas__bas__rr__v01)
export(vars_mh_y_bisbas__bis)
export(vars_mh_y_bisbas__bis__v01)
export(vars_mh_y_bpm)
export(vars_mh_y_bpm__attn)
export(vars_mh_y_bpm__ext)
export(vars_mh_y_bpm__int)
export(vars_mh_y_erq__reapp)
export(vars_mh_y_erq__suppr)
export(vars_mh_y_ksads__bpd__past__sx)
export(vars_mh_y_ksads__bpd__pres__sx)
export(vars_mh_y_ksads__cond__past__sx)
export(vars_mh_y_ksads__cond__pres__sx)
export(vars_mh_y_ksads__dep__past__sx)
export(vars_mh_y_ksads__dep__pres__sx)
export(vars_mh_y_ksads__dmdd__sx)
export(vars_mh_y_ksads__ed__past__sx)
export(vars_mh_y_ksads__ed__pres__sx)
export(vars_mh_y_ksads__gad__past__sx)
export(vars_mh_y_ksads__gad__pres__sx)
export(vars_mh_y_ksads__ocd__past__sx)
export(vars_mh_y_ksads__ocd__pres__sx)
export(vars_mh_y_ksads__panic__past__sx)
export(vars_mh_y_ksads__panic__pres__sx)
export(vars_mh_y_ksads__ptsd__past__sx)
export(vars_mh_y_ksads__ptsd__pres__sx)
export(vars_mh_y_ksads__sleep__past__sx)
export(vars_mh_y_ksads__sleep__pres__sx)
export(vars_mh_y_ksads__socanx__past__sx)
export(vars_mh_y_ksads__socanx__pres__sx)
export(vars_mh_y_ksads__suic__past__sx)
export(vars_mh_y_ksads__suic__pres__sx)
export(vars_mh_y_pai)
export(vars_mh_y_peq__overt__agg)
export(vars_mh_y_peq__overt__vict)
export(vars_mh_y_peq__rel__agg)
export(vars_mh_y_peq__rel__vict)
export(vars_mh_y_peq__rep__agg)
export(vars_mh_y_peq__rep__vict)
export(vars_mh_y_ple)
export(vars_mh_y_ple__exp)
export(vars_mh_y_ple__exp__v01)
export(vars_mh_y_ple__exp__v02)
export(vars_mh_y_ple__exp__v03)
export(vars_mh_y_ple__severity)
export(vars_mh_y_ple__severity__v01)
export(vars_mh_y_ple__severity__v02)
export(vars_mh_y_ple__severity__v03)
export(vars_mh_y_ple__v01)
export(vars_mh_y_ple__v02)
export(vars_mh_y_ple__v03)
export(vars_mh_y_pps__bother)
export(vars_mh_y_pps__severity)
export(vars_mh_y_pps_count)
export(vars_mh_y_sup)
export(vars_mh_y_upps__nurg)
export(vars_mh_y_upps__pers)
export(vars_mh_y_upps__plan)
export(vars_mh_y_upps__purg)
export(vars_mh_y_upps__sens)
export(vars_mh_y_ysr)
export(vars_mh_y_ysr__dsm__adhd)
export(vars_mh_y_ysr__dsm__anx)
export(vars_mh_y_ysr__dsm__cond)
export(vars_mh_y_ysr__dsm__dep)
export(vars_mh_y_ysr__dsm__opp)
export(vars_mh_y_ysr__dsm__somat)
export(vars_mh_y_ysr__pos)
export(vars_mh_y_ysr__synd__aggr)
export(vars_mh_y_ysr__synd__anxdep)
export(vars_mh_y_ysr__synd__attn)
export(vars_mh_y_ysr__synd__ext)
export(vars_mh_y_ysr__synd__int)
export(vars_mh_y_ysr__synd__othpr)
export(vars_mh_y_ysr__synd__rule)
export(vars_mh_y_ysr__synd__soc)
export(vars_mh_y_ysr__synd__som)
export(vars_mh_y_ysr__synd__tho)
export(vars_mh_y_ysr__synd__wthdep)
export(vars_nc_p_bdefs)
export(vars_nc_y_ehis)
export(vars_nt_p_yst__pmum)
export(vars_nt_p_yst__screen__wkdy)
export(vars_nt_p_yst__screen__wknd)
export(vars_nt_y_stq__screen__wkdy)
export(vars_nt_y_stq__screen__wknd)
export(vars_ph_p_anthr__height)
export(vars_ph_p_cna)
export(vars_ph_p_dhx_birthweight)
export(vars_ph_p_otbi)
export(vars_ph_p_otbi__loc__30m_count)
export(vars_ph_p_otbi__loc_before15)
export(vars_ph_p_otbi__loc_count)
export(vars_ph_p_otbi__loc_tbiage)
export(vars_ph_p_otbi__rpt_count)
export(vars_ph_p_otbi__tbi1a)
export(vars_ph_p_otbi__tbi1b)
export(vars_ph_p_otbi__tbi2)
export(vars_ph_p_otbi__tbi3)
export(vars_ph_p_otbi_tbiworst)
export(vars_ph_p_pds__f)
export(vars_ph_p_pds__f_categ)
export(vars_ph_p_pds__m)
export(vars_ph_p_pds__m_categ)
export(vars_ph_p_sds__da)
export(vars_ph_p_sds__dims)
export(vars_ph_p_sds__does)
export(vars_ph_p_sds__hyphy)
export(vars_ph_p_sds__sbd)
export(vars_ph_p_sds__swtd)
export(vars_ph_p_sds_sum)
export(vars_ph_y_anthr__height)
export(vars_ph_y_anthr__weight)
export(vars_ph_y_bp__dia)
export(vars_ph_y_bp__hrate)
export(vars_ph_y_bp__sys)
export(vars_ph_y_pds__f)
export(vars_ph_y_pds__f_categ)
export(vars_ph_y_pds__m)
export(vars_ph_y_pds__m_categ)
export(vars_su_p_ksads__aud__past__sx)
export(vars_su_p_ksads__aud__pres__sx)
export(vars_su_p_ksads__dud__coc__past__sx_mean)
export(vars_su_p_ksads__dud__coc__pres__sx_mean)
export(vars_su_p_ksads__dud__hall__past__sx_mean)
export(vars_su_p_ksads__dud__hall__pres__sx_mean)
export(vars_su_p_ksads__dud__mj__past__sx_mean)
export(vars_su_p_ksads__dud__mj__pres__sx_mean)
export(vars_su_p_ksads__dud__nic__past__sx_mean)
export(vars_su_p_ksads__dud__nic__pres__sx_mean)
export(vars_su_p_ksads__dud__opi__past__sx_mean)
export(vars_su_p_ksads__dud__opi__pres__sx_mean)
export(vars_su_p_ksads__dud__othdrg__past__sx_mean)
export(vars_su_p_ksads__dud__othdrg__pres__sx_mean)
export(vars_su_p_ksads__dud__past__sx_mean)
export(vars_su_p_ksads__dud__pcp__past__sx_mean)
export(vars_su_p_ksads__dud__pcp__pres__sx_mean)
export(vars_su_p_ksads__dud__pres__sx_mean)
export(vars_su_p_ksads__dud__sed__past__sx_mean)
export(vars_su_p_ksads__dud__sed__pres__sx_mean)
export(vars_su_p_ksads__dud__solv__past__sx_mean)
export(vars_su_p_ksads__dud__solv__pres__sx_mean)
export(vars_su_p_ksads__dud__stim__past__sx_mean)
export(vars_su_p_ksads__dud__stim__pres__sx_mean)
export(vars_su_y_alcexp__neg)
export(vars_su_y_alcexp__pos)
export(vars_su_y_alchss)
export(vars_su_y_alcprob)
export(vars_su_y_alcsre__6mo)
export(vars_su_y_alcsre__first5)
export(vars_su_y_alcsre__hvy)
export(vars_su_y_caff__coffee)
export(vars_su_y_caff__energy)
export(vars_su_y_caff__energy__drink)
export(vars_su_y_caff__energy__shot)
export(vars_su_y_caff__espres)
export(vars_su_y_caff__oth)
export(vars_su_y_caff__soda)
export(vars_su_y_caff__suppl)
export(vars_su_y_caff__tea)
export(vars_su_y_cigexp__neg)
export(vars_su_y_cigexp__pos)
export(vars_su_y_drgprob)
export(vars_su_y_ksads__aud__past__sx)
export(vars_su_y_ksads__aud__pres__sx)
export(vars_su_y_ksads__dud__coc__past__sx_mean)
export(vars_su_y_ksads__dud__coc__pres__sx_mean)
export(vars_su_y_ksads__dud__hall__past__sx_mean)
export(vars_su_y_ksads__dud__hall__pres__sx_mean)
export(vars_su_y_ksads__dud__mj__past__sx_mean)
export(vars_su_y_ksads__dud__mj__pres__sx_mean)
export(vars_su_y_ksads__dud__nic__past__sx_mean)
export(vars_su_y_ksads__dud__nic__pres__sx_mean)
export(vars_su_y_ksads__dud__opi__past__sx_mean)
export(vars_su_y_ksads__dud__opi__pres__sx_mean)
export(vars_su_y_ksads__dud__othdrg__past__sx_mean)
export(vars_su_y_ksads__dud__othdrg__pres__sx_mean)
export(vars_su_y_ksads__dud__past__sx_mean)
export(vars_su_y_ksads__dud__pcp__past__sx_mean)
export(vars_su_y_ksads__dud__pcp__pres__sx_mean)
export(vars_su_y_ksads__dud__pres__sx_mean)
export(vars_su_y_ksads__dud__sed__past__sx_mean)
export(vars_su_y_ksads__dud__sed__pres__sx_mean)
export(vars_su_y_ksads__dud__solv__past__sx_mean)
export(vars_su_y_ksads__dud__solv__pres__sx_mean)
export(vars_su_y_ksads__dud__stim__past__sx_mean)
export(vars_su_y_ksads__dud__stim__pres__sx_mean)
export(vars_su_y_mjexp__neg)
export(vars_su_y_mjexp__pos)
export(vars_su_y_mjprob)
export(vars_su_y_mjsre)
export(vars_su_y_mjsre__neg)
export(vars_su_y_mjsre__pos)
export(vars_su_y_nicsre__chew)
export(vars_su_y_nicsre__cig)
export(vars_su_y_nicsre__vape)
export(vars_su_y_nicvapeexp__neg)
export(vars_su_y_nicvapeexp__pos)
import(dplyr)
importFrom(cli,cli_abort)
importFrom(lubridate,as_datetime)
importFrom(lubridate,days)
importFrom(lubridate,interval)
importFrom(lubridate,years)
importFrom(magrittr,"%>%")
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,setNames)
importFrom(tibble,tibble)
importFrom(tibble,tribble)
importFrom(utils,capture.output)
importFrom(utils,head)
