% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_ph.R
\name{compute_ph_p_otbi__tbi4}
\alias{compute_ph_p_otbi__tbi4}
\title{Compute "Ohio State Traumatic Brain Injury Screen [Parent]: Moderate TBI"}
\usage{
compute_ph_p_otbi__tbi4(
  data,
  name = "ph_p_otbi__tbi4",
  exclude = c("777", "999"),
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score column.}

\item{exclude}{character vector. Values to be excluded from the summary
score calculation.}

\item{combine}{logical. If \code{TRUE} (default), the summary score is
is appended as a new column to the input data frame. If \code{FALSE}, the
summary score is returned as a separate one-column data frame.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{ph_p_otbi__tbi4}
Ohio State Traumatic Brain Injury Screen [Parent]: Moderate TBI
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{ph_p_otbi_001}
\item \code{ph_p_otbi_002}
\item \code{ph_p_otbi_003}
\item \code{ph_p_otbi_004}
\item \code{ph_p_otbi_005}
\item \code{ph_p_otbi__loc_001}
\item \code{ph_p_otbi__loc_002}
\item \code{ph_p_otbi__loc_003}
\item \code{ph_p_otbi__loc_004}
\item \code{ph_p_otbi__loc_005}
\item \code{ph_p_otbi__loc__add_001}
\item \code{ph_p_otbi__loc__add_001__02}
\item \code{ph_p_otbi__loc__add_001__03}
\item \code{ph_p_otbi__rpt_001}
\item \code{ph_p_otbi__rpt__loc_001}
\item \code{ph_p_otbi_001__l}
\item \code{ph_p_otbi_002__l}
\item \code{ph_p_otbi_003__l}
\item \code{ph_p_otbi_004__l}
\item \code{ph_p_otbi_005__l}
\item \code{ph_p_otbi__loc_001__l}
\item \code{ph_p_otbi__loc_002__l}
\item \code{ph_p_otbi__loc_003__l}
\item \code{ph_p_otbi__loc_004__l}
\item \code{ph_p_otbi__loc_005__l}
\item \code{ph_p_otbi__loc__add_001__l}
\item \code{ph_p_otbi__loc__add_001__02__l}
\item \code{ph_p_otbi__loc__add_001__03__l}
\item \code{ph_p_otbi__rpt_001__l}
\item \code{ph_p_otbi__rpt__loc_001__l}
}
\item \emph{Excluded values:}
\itemize{
\item 777
\item 999
}
}
}
\seealso{
\code{\link[=compute_ph_p_otbi__tbi3]{compute_ph_p_otbi__tbi3()}}
}
\keyword{internal}
