% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh.R
\name{compute_mh_y_ple__severity__good_mean__v03}
\alias{compute_mh_y_ple__severity__good_mean__v03}
\title{Compute "Life Events [Youth] (Severity of Good Events): Mean - Version
3 (Starting at Year 6) [Validation: No more than 6 events missing and no
experience/severity items missing or declined]"}
\usage{
compute_mh_y_ple__severity__good_mean__v03(
  data,
  name = "mh_y_ple__severity__good_mean__v03",
  events = c("ses-06A", "ses-07A"),
  combine = TRUE,
  max_na = 6
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the new column to be created (Default:
the name used in the ABCD data release).}

\item{events}{character vector. Event (session ID) to be used.}

\item{combine}{logical. If TRUE, the new column will be bound to the input
data frame. If FALSE, the new column will be created as a new data frame.}

\item{max_na}{numeric, positive whole number. Number of missing items
allowed (Default: 6).}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{mh_y_ple__severity__good_mean__v03}
Life Events [Youth] (Severity of Good Events): Mean - Version 3
(Starting at Year 6) [Validation: No more than 6 events missing and no
experience/severity items missing or declined]
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{mh_y_ple__exp_001}
\item \code{mh_y_ple__exp_002}
\item \code{mh_y_ple__exp_003}
\item \code{mh_y_ple__exp_004}
\item \code{mh_y_ple__exp_005}
\item \code{mh_y_ple__exp_006}
\item \code{mh_y_ple__exp_007}
\item \code{mh_y_ple__exp_008}
\item \code{mh_y_ple__exp_009}
\item \code{mh_y_ple__exp_010}
\item \code{mh_y_ple__exp_011}
\item \code{mh_y_ple__exp_012}
\item \code{mh_y_ple__exp_013}
\item \code{mh_y_ple__exp_014}
\item \code{mh_y_ple__exp_015}
\item \code{mh_y_ple__exp_016}
\item \code{mh_y_ple__exp_017}
\item \code{mh_y_ple__exp_018}
\item \code{mh_y_ple__exp_019}
\item \code{mh_y_ple__exp_020}
\item \code{mh_y_ple__exp_021}
\item \code{mh_y_ple__exp_022}
\item \code{mh_y_ple__exp_023}
\item \code{mh_y_ple__exp_024}
\item \code{mh_y_ple__exp_025}
\item \code{mh_y_ple__exp_026}
\item \code{mh_y_ple__exp_027}
\item \code{mh_y_ple__exp_028}
\item \code{mh_y_ple__exp_029}
\item \code{mh_y_ple__exp_030}
\item \code{mh_y_ple__exp_031}
\item \code{mh_y_ple__exp_032}
\item \code{mh_y_ple__exp_033}
\item \code{mh_y_ple__severity_001}
\item \code{mh_y_ple__severity_002}
\item \code{mh_y_ple__severity_003}
\item \code{mh_y_ple__severity_004}
\item \code{mh_y_ple__severity_005}
\item \code{mh_y_ple__severity_006}
\item \code{mh_y_ple__severity_007}
\item \code{mh_y_ple__severity_008}
\item \code{mh_y_ple__severity_009}
\item \code{mh_y_ple__severity_010}
\item \code{mh_y_ple__severity_011}
\item \code{mh_y_ple__severity_012}
\item \code{mh_y_ple__severity_013}
\item \code{mh_y_ple__severity_014}
\item \code{mh_y_ple__severity_015}
\item \code{mh_y_ple__severity_016}
\item \code{mh_y_ple__severity_017}
\item \code{mh_y_ple__severity_018}
\item \code{mh_y_ple__severity_019}
\item \code{mh_y_ple__severity_020}
\item \code{mh_y_ple__severity_021}
\item \code{mh_y_ple__severity_022}
\item \code{mh_y_ple__severity_023}
\item \code{mh_y_ple__severity_024}
\item \code{mh_y_ple__severity_025}
\item \code{mh_y_ple__severity_026}
\item \code{mh_y_ple__severity_027}
\item \code{mh_y_ple__severity_028}
\item \code{mh_y_ple__severity_029}
\item \code{mh_y_ple__severity_030}
\item \code{mh_y_ple__severity_031}
\item \code{mh_y_ple__severity_032}
\item \code{mh_y_ple__severity_033}
}
\item \emph{Excluded values:}
\itemize{
\item 444
\item 777
\item 999
}
\item \emph{Validation criterion:} maximally 6 of 33 items missing
}
}
