% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{famhx_config}
\alias{famhx_config}
\title{Configuration for parent Family history calculations}
\format{
A data frame with 96 rows and 4 columns:
\describe{
\item{name}{Name of the summary scores to be computed.}
\item{input_vars}{
Prefix or basename of the checkbox field used to compute
the summary score. The prefix provided in \code{input_vars} is used to
identify all fields associated with the checkbox, one column per
checkbox option; matches the regex \verb{^\{input_vars\}*}.
}
\item{fun}{The function used to compute the summary score.}
\item{call}{
The complete call to the function specified in \code{fun},
displaying the values of different parameters used in the function.
}
}
}
\usage{
famhx_config
}
\description{
Settings for processing family history of substance use data.
}
\keyword{datasets}
\keyword{internal}
