% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{data_tlfb_sample}
\alias{data_tlfb_sample}
\title{Sample dataset of Timeline Followback assessment}
\format{
An object of class \code{tbl_df} (inherits from \code{tbl}, \code{data.frame}) with 8 rows and 10 columns.
}
\usage{
data_tlfb_sample
}
\description{
Sample TLFB data for testing and examples.
}
\keyword{datasets}
\keyword{internal}
