% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh_aseba.R
\name{compute_mh_p_asr__synd__anxdep_sum}
\alias{compute_mh_p_asr__synd__anxdep_sum}
\title{Compute "Adult Self Report [Parent] (Syndrome Scale - Anxious/Depressed):
Sum"}
\usage{
compute_mh_p_asr__synd__anxdep_sum(
  data,
  name = "mh_p_asr__synd__anxdep_sum",
  max_na = 1,
  exclude = c("777", "999"),
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score column.}

\item{max_na}{numeric, positive whole number. Number of missing items
allowed. \code{NULL} means no limit.}

\item{exclude}{character vector. Values to be excluded from the summary score.}

\item{combine}{logical. If \code{TRUE} (default), the summary score is
is appended as a new column to the input data frame. If \code{FALSE}, the
summary score is returned as a separate one-column data frame.}
}
\value{
tbl. see \code{combine}.
}
\description{
Computes the summary score \code{mh_p_asr__synd__anxdep_sum}
Adult Self Report [Parent] (Syndrome Scale - Anxious/Depressed): Sum
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{mh_p_asr__anxdep_001}
\item \code{mh_p_asr__anxdep_002}
\item \code{mh_p_asr__anxdep_003}
\item \code{mh_p_asr__anxdep_004}
\item \code{mh_p_asr__anxdep_005}
\item \code{mh_p_asr__anxdep_006}
\item \code{mh_p_asr__anxdep__anx_001}
\item \code{mh_p_asr__anxdep__anx_002}
\item \code{mh_p_asr__anxdep__anx_003}
\item \code{mh_p_asr__anxdep__anx_004}
\item \code{mh_p_asr__anxdep__avoid_001}
\item \code{mh_p_asr__anxdep__avoid_002}
\item \code{mh_p_asr__anxdep__dep_001}
\item \code{mh_p_asr__anxdep__dep_002}
\item \code{mh_p_asr__anxdep__dep_003}
\item \code{mh_p_asr__anxdep__dep_004}
\item \code{mh_p_asr__anxdep__dep_005}
\item \code{mh_p_asr__anxdep__dep_006}
}
\item \emph{Excluded values:}
\itemize{
\item 777
\item 999
}
\item \emph{Validation criterion:} maximally 1 of 18 items missing
}
}
\examples{
\dontrun{
compute_mh_p_asr__synd__anxdep_sum(data) |>
  select(
    any_of(c("mh_p_asr__synd__anxdep_sum", vars_mh_p_asr__synd__anxdep))
  )
}
}
\seealso{
\code{\link[=compute_mh_p_asr__synd__anxdep_nm]{compute_mh_p_asr__synd__anxdep_nm()}}
}
