% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_ph.R
\docType{data}
\name{vars_ph_p_sds__swtd}
\alias{vars_ph_p_sds__swtd}
\alias{compute_ph_p_sds__swtd_sum}
\title{Compute "Sleep Disturbance Scale [Parent] (Sleep-wake transition
disorders): Sum [Validation: No more than 0 missing or declined]"}
\format{
character vector of all column names
used to compute summary scores of \code{ph_p_sds__swtd_sum} and \code{ph_p_sds__swtd_nm}.
}
\usage{
vars_ph_p_sds__swtd

compute_ph_p_sds__swtd_sum(
  data,
  name = "ph_p_sds__swtd_sum",
  max_na = 0,
  exclude = c("777", "999"),
  combine = TRUE
)
}
\arguments{
\item{data}{tbl, Dataframe containing the columns to be summarized.}

\item{name}{character, Name of the new column to be created. Default is
the name in description, but users can change it.}

\item{max_na}{integer, Maximum number of missing values allowed in the
summary score. \code{NULL} means no limit.}

\item{exclude}{character, Values to be excluded from the summary score.}

\item{combine}{logical, If \code{TRUE}, the summary score will be appended to
the input data frame. If \code{FALSE}, the summary score will be returned as a
separate data frame.}
}
\description{
Computes the summary score \code{ph_p_sds__swtd_sum}
Sleep Disturbance Scale [Parent] (Sleep-wake transition disorders): Sum
[Validation: No more than 0 missing or declined]
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{ph_p_sds__swtd_001}
\item \code{ph_p_sds__swtd_002}
\item \code{ph_p_sds__swtd_003}
\item \code{ph_p_sds__swtd_004}
\item \code{ph_p_sds__swtd_005}
\item \code{ph_p_sds__swtd_006}
}
\item \emph{Excluded values:}
\itemize{
\item 777
\item 999
}
\item \emph{Validation criterion:} maximally 0 items missing
}
}
\examples{
\dontrun{
compute_ph_p_sds__swtd_sum(data) |>
  select(
    all_of(c("ph_p_sds__swtd_sum", vars_ph_p_sds__swtd))
  )
}
}
\keyword{datasets}
