% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{sui_config}
\alias{sui_config}
\title{Configuration for Substance Use Interview calculations}
\format{
An object of class \code{tbl_df} (inherits from \code{tbl}, \code{data.frame}) with 100 rows and 5 columns.
}
\usage{
sui_config
}
\description{
Settings for processing SUI substance use data.
}
\keyword{datasets}
\keyword{internal}
