% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh_aseba.R
\name{compute_mh_y_ysr__synd__som_sum}
\alias{compute_mh_y_ysr__synd__som_sum}
\title{Compute "Youth Self Report [Youth] (Syndrome Scale - Somatic complaints):
Sum"}
\usage{
compute_mh_y_ysr__synd__som_sum(
  data,
  name = "mh_y_ysr__synd__som_sum",
  max_na = 2,
  exclude = c("777", "999"),
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score column.}

\item{max_na}{numeric, positive whole number. Number of missing items
allowed. \code{NULL} means no limit.}

\item{exclude}{character vector. Values to be excluded from the summary score.}

\item{combine}{logical. If \code{TRUE} (default), the summary score is
is appended as a new column to the input data frame. If \code{FALSE}, the
summary score is returned as a separate one-column data frame.}
}
\value{
tbl. see \code{combine}.
}
\description{
Computes the summary score \code{mh_y_ysr__synd__som_sum}
Youth Self Report [Youth] (Syndrome Scale - Somatic complaints): Sum
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{mh_y_ysr__som__anx_001}
\item \code{mh_y_ysr__som_001}
\item \code{mh_y_ysr__som__dep_001}
\item \code{mh_y_ysr__som__somat_001}
\item \code{mh_y_ysr__som__somat_002}
\item \code{mh_y_ysr__som__somat_003}
\item \code{mh_y_ysr__som__somat_004}
\item \code{mh_y_ysr__som__somat_005}
\item \code{mh_y_ysr__som__somat_006}
\item \code{mh_y_ysr__som__somat_007}
}
\item \emph{Excluded values:}
\itemize{
\item 777
\item 999
}
\item \emph{Validation criterion:} maximally 2 of 10 items missing
}
}
\examples{
\dontrun{
compute_mh_y_ysr__synd__som_sum(data) |>
  select(
    any_of(c("mh_y_ysr__synd__som_sum", vars_mh_y_ysr__synd__som))
  )
}
}
\seealso{
\code{\link[=compute_mh_y_ysr__synd__som_nm]{compute_mh_y_ysr__synd__som_nm()}}
}
