% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_nt_fitbit.R
\name{identify_hr_recovery}
\alias{identify_hr_recovery}
\title{Identify Recoverable Heart Rate Gaps During Sleep}
\usage{
identify_hr_recovery(data)
}
\arguments{
\item{data}{tbl. Data frame heart rate column \code{hrate}, \code{session_id} & \code{dtt}.
\code{data} is the output from the \code{identify_hr_exclusions()}.}
}
\value{
tbl. The input data frame with the following additional columns:
\itemize{
\item \code{recover_hr}: TRUE if interval can should be excluded based on adjacency
to plausible sleep.
}
}
\description{
Identifies period of missing heart rate during sleep that can be recovered
based on adjacent sleep minutes with valid heart rate. Specifically,
identifies sequences of heart rate values during sleep that end at 23:59 and
immediately followed by sleep periods with valid heart rate values. These
segments are marked as recoverable.
}
\keyword{internal}
