% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_ph.R
\name{compute_ph_p_anthr__moth_height__in}
\alias{compute_ph_p_anthr__moth_height__in}
\title{Compute "Anthropometrics [Parent] (Height): Mother's height (in)"}
\usage{
compute_ph_p_anthr__moth_height__in(
  data,
  name = "ph_p_anthr__moth_height__in",
  combine = TRUE
)
}
\arguments{
\item{data}{tbl, Dataframe containing the columns to be summarized.}

\item{name}{character, Name of the new column to be created. Default is
the name in description, but users can change it.}

\item{combine}{logical, If \code{TRUE}, the summary score will be appended to
the input data frame. If \code{FALSE}, the summary score will be returned as a
separate data frame.}
}
\description{
Computes the summary score \code{ph_p_anthr__moth_height__in}
Anthropometrics [Parent] (Height): Mother's height (in)
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{ph_p_anthr__height__moth_001}
\item \code{ph_p_anthr__height__moth_001__01}
}
\item \emph{Excluded values:} None
\item \emph{Validation criterion:} None
}
}
\examples{
\dontrun{
compute_ph_p_anthr__moth_height__in(data) |>
  select(
    all_of(c("ph_p_anthr__moth_height__in", vars_ph_p_anthr__height))
  )
}
}
\seealso{
\code{\link[=compute_ph_p_anthr__fath_height__in]{compute_ph_p_anthr__fath_height__in()}}
}
