% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_su_tlfb_sui_sdsu.R
\name{check_args_sdsu}
\alias{check_args_sdsu}
\title{Check arguments for Static and Dynamic Substance Use (SDSU) scores functions}
\usage{
check_args_sdsu(data = data, name = name)
}
\arguments{
\item{data}{tibble. Input data frame to validate.}

\item{name}{character(1). Name of the output score column to validate.}
}
\value{
invisible NULL. Throws an error if checks fail.
}
\description{
Validates the arguments to compute a SDSU score.
}
\keyword{internal}
