% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh_aseba.R
\docType{data}
\name{vars_mh_p_asr}
\alias{vars_mh_p_asr}
\alias{compute_mh_p_asr_nm}
\title{Compute "Adult Self Report [Parent]: Number missing"}
\format{
\code{vars_mh_p_asr} is vector of all column names
used to compute summary score of \code{mh_p_asr} scores.
}
\usage{
vars_mh_p_asr

compute_mh_p_asr_nm(
  data,
  name = "mh_p_asr_nm",
  exclude = c("777", "999"),
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score column.}

\item{exclude}{character vector. Values to be excluded from the summary score.}

\item{combine}{logical. If \code{TRUE} (default), the summary score is
is appended as a new column to the input data frame. If \code{FALSE}, the
summary score is returned as a separate one-column data frame.}
}
\value{
tbl. see \code{combine}.
}
\description{
Computes the summary score \code{mh_p_asr_nm}
Adult Self Report [Parent]: Number missing
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{mh_p_asr__aggr_001}
\item \code{mh_p_asr__aggr__antsoc_003}
\item \code{mh_p_asr__aggr__antsoc_006}
\item \code{mh_p_asr__aggr__antsoc_008}
\item \code{mh_p_asr__anxdep__dep_001}
\item \code{mh_p_asr__anxdep__dep_004}
\item \code{mh_p_asr__anxdep__dep_005}
\item \code{mh_p_asr__attn__inatt_002}
\item \code{mh_p_asr__othpr__hypimp_001}
\item \code{mh_p_asr__othpr__antsoc_001}
\item \code{mh_p_asr__rule_001}
\item \code{mh_p_asr__rule_003}
\item \code{mh_p_asr__rule__antsoc_007}
\item \code{mh_p_asr__tho_001}
\item \code{mh_p_asr__tho_002}
\item \code{mh_p_asr__tho_005}
\item \code{mh_p_asr__tho_006}
\item \code{mh_p_asr__tho_007}
\item \code{mh_p_asr__tho__dep_001}
\item \code{mh_p_asr__aggr__hypimp_001}
\item \code{mh_p_asr__othpr__hypimp_002}
\item \code{mh_p_asr__othpr__hypimp_003}
\item \code{mh_p_asr__rule__hypimp_001}
\item \code{mh_p_asr__tho__hypimp_001}
\item \code{mh_p_asr__attn__inatt_001}
\item \code{mh_p_asr__attn__inatt_003}
\item \code{mh_p_asr__attn__inatt_004}
\item \code{mh_p_asr__attn__inatt_005}
\item \code{mh_p_asr__attn__inatt_006}
\item \code{mh_p_asr__attn__inatt_007}
\item \code{mh_p_asr__aggr__antsoc_001}
\item \code{mh_p_asr__aggr__antsoc_002}
\item \code{mh_p_asr__aggr__antsoc_004}
\item \code{mh_p_asr__aggr__antsoc_005}
\item \code{mh_p_asr__aggr__antsoc_007}
\item \code{mh_p_asr__attn__antsoc_001}
\item \code{mh_p_asr__othpr__antsoc_002}
\item \code{mh_p_asr__rule__antsoc_001}
\item \code{mh_p_asr__rule__antsoc_002}
\item \code{mh_p_asr__rule__antsoc_003}
\item \code{mh_p_asr__rule__antsoc_004}
\item \code{mh_p_asr__rule__antsoc_005}
\item \code{mh_p_asr__rule__antsoc_006}
\item \code{mh_p_asr__rule__antsoc_008}
\item \code{mh_p_asr__rule__antsoc_009}
\item \code{mh_p_asr__anxdep__anx_001}
\item \code{mh_p_asr__anxdep__anx_002}
\item \code{mh_p_asr__anxdep__anx_003}
\item \code{mh_p_asr__anxdep__anx_004}
\item \code{mh_p_asr__othpr__anx_001}
\item \code{mh_p_asr__othpr__anx_002}
\item \code{mh_p_asr__anxdep__avoid_001}
\item \code{mh_p_asr__anxdep__avoid_002}
\item \code{mh_p_asr__othpr__avoid_001}
\item \code{mh_p_asr__wthdr__avoid_001}
\item \code{mh_p_asr__wthdr__avoid_002}
\item \code{mh_p_asr__wthdr__avoid_003}
\item \code{mh_p_asr__wthdr__avoid_004}
\item \code{mh_p_asr__anxdep__dep_002}
\item \code{mh_p_asr__anxdep__dep_003}
\item \code{mh_p_asr__anxdep__dep_006}
\item \code{mh_p_asr__attn__dep_001}
\item \code{mh_p_asr__attn__dep_002}
\item \code{mh_p_asr__othpr__dep_001}
\item \code{mh_p_asr__othpr__dep_002}
\item \code{mh_p_asr__som__dep_001}
\item \code{mh_p_asr__som__dep_002}
\item \code{mh_p_asr__wthdr__dep_001}
\item \code{mh_p_asr__som__somat_001}
\item \code{mh_p_asr__som__somat_002}
\item \code{mh_p_asr__som__somat_003}
\item \code{mh_p_asr__som__somat_004}
\item \code{mh_p_asr__som__somat_005}
\item \code{mh_p_asr__som__somat_006}
\item \code{mh_p_asr__som__somat_007}
\item \code{mh_p_asr__som__somat_008}
\item \code{mh_p_asr__som__somat_009}
\item \code{mh_p_asr__aggr_002}
\item \code{mh_p_asr__aggr_003}
\item \code{mh_p_asr__aggr_004}
\item \code{mh_p_asr__aggr_005}
\item \code{mh_p_asr__aggr_006}
\item \code{mh_p_asr__anxdep_001}
\item \code{mh_p_asr__anxdep_002}
\item \code{mh_p_asr__anxdep_003}
\item \code{mh_p_asr__anxdep_004}
\item \code{mh_p_asr__anxdep_005}
\item \code{mh_p_asr__anxdep_006}
\item \code{mh_p_asr__attn_001}
\item \code{mh_p_asr__attn_002}
\item \code{mh_p_asr__attn_003}
\item \code{mh_p_asr__attn_004}
\item \code{mh_p_asr__attn_005}
\item \code{mh_p_asr__intru_001}
\item \code{mh_p_asr__intru_002}
\item \code{mh_p_asr__intru_003}
\item \code{mh_p_asr__intru_004}
\item \code{mh_p_asr__intru_005}
\item \code{mh_p_asr__intru_006}
\item \code{mh_p_asr__rule_002}
\item \code{mh_p_asr__rule_004}
\item \code{mh_p_asr__som_001}
\item \code{mh_p_asr__wthdr_001}
\item \code{mh_p_asr__wthdr_002}
\item \code{mh_p_asr__wthdr_003}
\item \code{mh_p_asr__wthdr_004}
\item \code{mh_p_asr__othpr_001}
\item \code{mh_p_asr__othpr_002}
\item \code{mh_p_asr__othpr_003}
\item \code{mh_p_asr__othpr_004}
\item \code{mh_p_asr__othpr_005}
\item \code{mh_p_asr__othpr_006}
\item \code{mh_p_asr__othpr_007}
\item \code{mh_p_asr__othpr_008}
\item \code{mh_p_asr__othpr_009}
\item \code{mh_p_asr__othpr_010}
\item \code{mh_p_asr__othpr_011}
\item \code{mh_p_asr__tho_003}
\item \code{mh_p_asr__tho_004}
\item \code{mh_p_asr__tho_008}
}
\item \emph{Excluded values:}
\itemize{
\item 777
\item 999
}
}
}
\examples{
\dontrun{
compute_mh_p_asr_nm(data) |>
  select(
    any_of(c("mh_p_asr_nm", vars_mh_p_asr))
  )
}
}
\keyword{datasets}
