% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_su.R
\docType{data}
\name{vars_su_y_cigexp__neg}
\alias{vars_su_y_cigexp__neg}
\alias{compute_su_y_cigexp__neg_prsum}
\title{Compute "Cigarette Expectancies (ASCQ) [Youth] (Strength of negative
expectancies): Prorated sum"}
\format{
vars_su_y_cigexp__neg is a character vector of all column names
used to compute summary score of \code{su_y_cigexp__neg_prsum} and
\code{su_y_cigexp__neg_nm}.
}
\usage{
vars_su_y_cigexp__neg

compute_su_y_cigexp__neg_prsum(
  data,
  name = "su_y_cigexp__neg_prsum",
  combine = TRUE,
  exclude = c("0"),
  max_na = 0
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character, Name of the new column to be created. Default is
the name in description, but users can change it.}

\item{combine}{logical, If \code{TRUE} (default), the summary score will be appended to
the input data frame. If \code{FALSE}, the summary score for each participant
will be returned as a separate data frame. (Default: TRUE)}

\item{exclude}{character vector. Values to be excluded from the summary
score calculation.}

\item{max_na}{numeric, positive whole number. Number of missing items
allowed (Default: 1).}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{su_y_cigexp__neg_prsum}
Cigarette Expectancies (ASCQ) [Youth] (Strength of negative
expectancies): Prorated sum [Validation: No more than 0
missing or declined]

Note: all 0s are changed to NAs prior to calculating pro-rated sum
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{su_y_cigexp__neg_001}
\item \code{su_y_cigexp__neg_002}
}
\item \emph{Excluded values:}
\itemize{
\item 0
}
\item \emph{Validation criterion:} maximally 0 of 2 items missing
}
}
\keyword{datasets}
