% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh.R
\name{compute_mh_p_eatq__inhib_nm}
\alias{compute_mh_p_eatq__inhib_nm}
\title{Compute "Early Adolescent Temperament Questionnaire [Parent] (Inhibition):
Number missing"}
\usage{
compute_mh_p_eatq__inhib_nm(data, name = "mh_p_eatq__inhib_nm", combine = TRUE)
}
\arguments{
\item{data}{tbl, Dataframe containing the columns to be summarized.}

\item{name}{character, Name of the new column to be created. Default is
the name in description, but users can change it.}

\item{combine}{logical, If \code{TRUE}, the summary score will be appended to
the input data frame. If \code{FALSE}, the summary score will be returned as a
separate data frame.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{mh_p_eatq__inhib_nm}
Early Adolescent Temperament Questionnaire [Parent] (Inhibition):
Number missing
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{mh_p_eatq__inhib_001}
\item \code{mh_p_eatq__inhib_002}
\item \code{mh_p_eatq__inhib_003}
\item \code{mh_p_eatq__inhib_004}
\item \code{mh_p_eatq__inhib_005}
}
\item \emph{Excluded values:} none
}
}
\examples{
\dontrun{
data <- compute_mh_p_eatq__inhib_nm(data)
select(
  data,
  any_of(c("mh_p_eatq__inhib_nm", vars_mh_p_eatq__inhib))
)
}

}
\seealso{
\code{\link[=compute_mh_p_eatq__inhib_mean]{compute_mh_p_eatq__inhib_mean()}}
}
