% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_nt_fitbit.R
\name{compute_fitbit_min_totals}
\alias{compute_fitbit_min_totals}
\title{Compute total valid minutes by day or by specified time bins}
\usage{
compute_fitbit_min_totals(data, bin_minutes)
}
\arguments{
\item{data}{tbl. Data frame with exclusion flags.}

\item{bin_minutes}{numeric, positive whole number. Number of minutes.}
}
\value{
A tibble with valid minute totals for each participant-event-period.
The output adds the following columns:
\itemize{
\item \code{min_total}: Total valid minutes (not excluded by heart rate criteria).
\item \code{min_actv}: Total valid non-sleep minutes.
\item \code{min_slp}: Total valid sleep minutes.
\item \code{min_nap_slp}: Total valid nap sleep minutes (sleep minutes that are not
main sleep).
\item \code{start}: If \code{bin_minutes} not daily (1440 minutes), start datetime of
period
\item \code{end}:  If \code{bin_minutes} not daily (1440 minutes), end datetime of period.
}
}
\description{
Computes the number of valid minutes, valid non-sleep minutes,
and valid sleep minutes for each participant and session, either by day or
by specified time bins.
}
\note{
\itemize{
\item output of identify_hr_exclusions() or identify_hr_recovery()
\item needs exclusion flags
}
}
\keyword{internal}
