% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh.R
\name{compute_mh_y_peq_all}
\alias{compute_mh_y_peq_all}
\title{Compute all summary scores for mh_y_peq.}
\usage{
compute_mh_y_peq_all(data)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}
}
\value{
tbl. The input data frame with the summary
scores appended as new columns.
}
\description{
This function computes all summary scores for the mh_y_peq table.
Make sure to have all necessary columns in the data frame.
}
\examples{
\dontrun{
compute_mh_y_peq_all(data)
}
}
