% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{rx_map}
\alias{rx_map}
\alias{rx_config}
\alias{rx_config_estuse_flags}
\title{Medical prescription Normalized Names mapping (RxNorm) data}
\format{
An object of class \code{list} of length 5.

An object of class \code{tbl_df} (inherits from \code{tbl}, \code{data.frame}) with 570 rows and 10 columns.

An object of class \code{tbl_df} (inherits from \code{tbl}, \code{data.frame}) with 475 rows and 4 columns.
}
\usage{
rx_map

rx_config

rx_config_estuse_flags
}
\description{
A list of medication data frames of 5 different categories:
\itemize{
\item rx_ingr: Ingredient Name
\item rx_pingr: Precise Ingredient Name
\item rx_mingr: Multiple Ingredients Name
\item rx_bn (BN): Brand Name
\item rx_estuse: Estimated Use Category
}

\code{rx_config} is a tibble with configuration settings for medication
score calculations.

Columns in \code{rx_config}:
\itemize{
\item med_type: character, medication type, either "otc" (over-the-counter) or
"rx" (prescription).
\item idx: character, index number as a string with leading zeros.
\item catg: character, category of medication mapping,
one of categories from \code{rx_map}.
\item table_name: character, table name for the score variable.
\item col_add: character, column name for additional filtering (if any) with
values "1" (yes) or "0" (no) or \code{NA}.
\item col_summary1: character, primary column name in the data frame containing
medication RxCUI.
\item use_col_add1: logical, whether to apply \code{col_add} filtering when
\code{col_summary1} has data.
\item col_summary2: character, secondary column name in the data frame
containing medication RxCUI; used when \code{col_summary1} is \code{NA}.
\item use_col_add2: logical, whether to apply \code{col_add} filtering when
\code{col_summary2} has data.
\item name: character, name of the new column to be created in the summary score.
}

Selection rule for RxCUI source columns:
\itemize{
\item Use \code{col_summary1} first when it has data.
\item Otherwise, use \code{col_summary2}.
\item Apply \code{col_add} only when the corresponding \verb{use_col_add*} flag is \code{TRUE}
and the selected summary column has data.
}

Columns in \code{rx_config_estuse_flags}:
\itemize{
\item time_point: character, time point of the medication data,
"1yr", or "2wk" or "24hr".
\item idx: character, index number as a string \strong{without} leading zeros.
\item table_name: character, table name for the score variable.
\item name: character, name of the new column to be created in the summary score.
}
}
\details{
\subsection{rx_map}{

In each data frame, \code{rx} is the RxCUI identifier, and \code{category} is the
value in that category.

Disclaimer: This product uses publicly available data from the U.S.
National Library of Medicine (NLM), National Institutes of Health,
Department of Health and Human Services; NLM is not responsible for
the product and does not endorse or recommend this or any other product.
}
}
\keyword{datasets}
\keyword{internal}
