% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh.R
\name{compute_mh_p_eatq_all}
\alias{compute_mh_p_eatq_all}
\title{Compute all the EATQ variables}
\usage{
compute_mh_p_eatq_all(data)
}
\arguments{
\item{data}{tbl, Dataframe containing the columns to be summarized.}
}
\value{
tbl. The input data frame with the summary scores appended as
new columns.
}
\description{
This super function computes all scores in EATQ using all the
\strong{default} arguments.
}
\details{
Make sure the \code{data} is the full set of all variables from EATQ
}
\examples{
\dontrun{
compute_mh_p_eatq_all(data)
}
}
