% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_nt_fitbit.R
\name{compute_fitbit_score_minutes_exclusion}
\alias{compute_fitbit_score_minutes_exclusion}
\title{Computes heart rate based exclusions totals by time period}
\usage{
compute_fitbit_score_minutes_exclusion(data, bin_minutes)
}
\arguments{
\item{data}{tbl. Data frame with exclusion flag columns \code{is_slp},
\code{session_id}, \code{dtt}, \code{hrate_excluded}, \code{hrate_low}, \code{hrate_hi} (optional),
\code{hrate_no}, \code{hrate_repeat_actv}, and \code{hrate_repeat_slp}.}

\item{bin_minutes}{numeric, positive whole number. Number of minutes to
bin data by.}
}
\value{
tbl. The input data frame with the following additional columns:
\itemize{
\item \code{excl_min_total_actv}: Total number of non-sleep minutes excluded by
heart rate criteria.
\item \code{excl_min_lowhrate_actv}: Total number of non-sleep minutes excluded by
low heart rate criteria.
\item \code{excl_min_highhrate_actv}: Total number of non-sleep minutes excluded by
high heart rate criteria (if \code{hrate_hi} exists). Column is not created if
\code{hrate_hi} does not exist.
\item \code{excl_min_nohrate_actv}: Total number of non-sleep minutes excluded by
missing heart rate criteria.
\item \code{excl_min_repeathrate_actv}: Total number of non-sleep minutes excluded by
repeat heart rate criteria.
\item \code{excl_min_total_slp}: Total number of sleep minutes excluded by heart rate
criteria.
\item \code{excl_min_lowhrate_slp}: Total number of sleep minutes excluded by low
heart rate criteria.
\item \code{excl_min_highhrate_slp}: Total number of sleep minutes excluded by high
heart rate criteria (if \code{hrate_hi} exists). Column is not created if
\code{hrate_hi} does not exist.
\item \code{excl_min_nohrate_slp}: Total number of sleep minutes excluded by missing
heart rate criteria.
\item \code{excl_min_repeathrate_slp}: Total number of sleep minutes excluded by
repeat heart rate criteria.
\item \code{start}: If non-daily bin selected (i.e. != 1440 minutes), start time
stamp of bin.
\item \code{end}:  If non-daily bin selected (i.e., != 1440 minutes), end time stamp
of the bin.
}
}
\description{
Computes heart rate based exclusions by day or by specified time bins.
}
\note{
\itemize{
\item output of identify_hr_exclusions() or identify_hr_recovery();
\item needs exclusion flags
}
}
\keyword{internal}
