% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_nt.R
\docType{data}
\name{vars_nt_y_stq__screen__wkdy}
\alias{vars_nt_y_stq__screen__wkdy}
\alias{compute_nt_y_stq__screen__wkdy_sum}
\title{Compute "Screen Time [Youth] (Weekday): Sum"}
\format{
vars_nt_y_stq__screen__wkdy is a character vector of all column names
used to compute summary score of \code{nt_y_stq__screen__wkdy}.
}
\usage{
vars_nt_y_stq__screen__wkdy

compute_nt_y_stq__screen__wkdy_sum(
  data,
  name = "nt_y_stq__screen__wkdy_sum",
  max_na = 0,
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the new column to be created (Default:
the name used in the ABCD data release).}

\item{max_na}{numeric, positive whole number. Number of missing items
allowed (Default: 0).}

\item{combine}{logical. If TRUE, the new column will be bound to the input
data frame. If FALSE, the new column will be created as a new data frame.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{nt_y_stq__screen__wkdy_sum}
Screen Time [Youth] (Weekday): Sum
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{nt_y_stq__screen__wkdy_001}
\item \code{nt_y_stq__screen__wkdy_002}
\item \code{nt_y_stq__screen__wkdy_003}
\item \code{nt_y_stq__screen__wkdy_004}
\item \code{nt_y_stq__screen__wkdy_005}
\item \code{nt_y_stq__screen__wkdy_006}
\item \code{nt_y_stq__screen__wkdy__hr_001}
\item \code{nt_y_stq__screen__wkdy__min_001}
\item \code{nt_y_stq__screen__wkdy__hr_001__v01}
\item \code{nt_y_stq__screen__wkdy__min_001__v01}
\item \code{nt_y_stq__screen__wkdy__hr_002}
\item \code{nt_y_stq__screen__wkdy__min_002}
\item \code{nt_y_stq__screen__wkdy__hr_003}
\item \code{nt_y_stq__screen__wkdy__min_003}
\item \code{nt_y_stq__screen__wkdy__hr_004}
\item \code{nt_y_stq__screen__wkdy__min_004}
\item \code{nt_y_stq__screen__wkdy__hr_005}
\item \code{nt_y_stq__screen__wkdy__min_005}
\item \code{nt_y_stq__screen__wkdy__hr_006}
\item \code{nt_y_stq__screen__wkdy__min_006}
\item \code{nt_y_stq__screen__wkdy__hr_007}
\item \code{nt_y_stq__screen__wkdy__min_007}
\item \code{nt_y_stq__screen__wkdy__hr_008}
\item \code{nt_y_stq__screen__wkdy__min_008}
\item \code{nt_y_stq__screen__wkdy__hr_009}
\item \code{nt_y_stq__screen__wkdy__min_009}
}
\item \emph{Excluded values:}
\itemize{
\item 777
\item 999
}
\item \emph{Validation criterion:} none missing
}
}
\keyword{datasets}
