% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh_aseba.R
\docType{data}
\name{vars_mh_t_bpm}
\alias{vars_mh_t_bpm}
\alias{compute_mh_t_bpm_nm}
\title{Compute "Brief Problem Monitor [Teacher]: Number missing"}
\format{
\code{vars_mh_t_bpm} is vector of all column names
used to compute summary score of \code{mh_t_bpm} scores.
}
\usage{
vars_mh_t_bpm

compute_mh_t_bpm_nm(
  data,
  name = "mh_t_bpm_nm",
  exclude = c("777", "999"),
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score column.}

\item{exclude}{character vector. Values to be excluded from the summary score.}

\item{combine}{logical. If \code{TRUE} (default), the summary score is
is appended as a new column to the input data frame. If \code{FALSE}, the
summary score is returned as a separate one-column data frame.}
}
\value{
tbl. see \code{combine}.
}
\description{
Computes the summary score \code{mh_t_bpm_nm}
Brief Problem Monitor [Teacher]: Number missing
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{mh_t_bpm__attn_001}
\item \code{mh_t_bpm__attn_002}
\item \code{mh_t_bpm__attn_003}
\item \code{mh_t_bpm__attn_004}
\item \code{mh_t_bpm__attn_005}
\item \code{mh_t_bpm__attn_006}
\item \code{mh_t_bpm__ext_001}
\item \code{mh_t_bpm__ext_002}
\item \code{mh_t_bpm__ext_003}
\item \code{mh_t_bpm__ext_004}
\item \code{mh_t_bpm__ext_005}
\item \code{mh_t_bpm__ext_006}
\item \code{mh_t_bpm__int_001}
\item \code{mh_t_bpm__int_002}
\item \code{mh_t_bpm__int_003}
\item \code{mh_t_bpm__int_004}
\item \code{mh_t_bpm__int_005}
\item \code{mh_t_bpm__int_006}
}
\item \emph{Excluded values:}
\itemize{
\item 777
\item 999
}
}
}
\examples{
\dontrun{
compute_mh_t_bpm_nm(data) |>
  select(
    any_of(c("mh_t_bpm_nm", vars_mh_t_bpm))
  )
}
}
\keyword{datasets}
