% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_ab.R
\docType{data}
\name{vars_ab_g_stc__cohort_ethnrace__mblack}
\alias{vars_ab_g_stc__cohort_ethnrace__mblack}
\alias{compute_ab_g_stc__cohort_ethnrace__mblack}
\title{Compute "Cohort description: Ethno-racial identity (8 level aggregation
providing information on Black identity for multiracial endorements) [Based
on baseline response; missingness filled in from longitudinal responses]"}
\format{
a character vector of all
column names used to compute summary score of
\code{ab_g_stc__cohort_ethnrace__mblack}.
}
\usage{
vars_ab_g_stc__cohort_ethnrace__mblack

compute_ab_g_stc__cohort_ethnrace__mblack(
  data,
  name = "ab_g_stc__cohort_ethnrace__mblack",
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character, Name of the new column to be created. Default is
the name in description, but users can change it.}

\item{combine}{logical, If \code{TRUE}, the summary score will be appended to
the input data frame. If \code{FALSE}, the summary score for each participant
will be returned as a separate data frame. (Default: FALSE)}
}
\value{
tbl. The input data frame with the summary score appended as
a new column (default). If \code{combine == FALSE}, a data frame with two
columns: participant ID and summary score.
}
\description{
Computes the summary score \code{ab_g_stc__cohort_ethnrace__mblack}
Cohort description: Ethno-racial identity (8 level aggregation providing
information on Black identity for multiracial endorements) [Based on
baseline response; missingness filled in from longitudinal responses]
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{ab_p_demo__ethn_001}
\item \code{ab_p_demo__ethn_001__v01}
\item \code{ab_p_demo__race_001___0}
\item \code{ab_p_demo__race_001___10}
\item \code{ab_p_demo__race_001___11}
\item \code{ab_p_demo__race_001___12}
\item \code{ab_p_demo__race_001___13}
\item \code{ab_p_demo__race_001___14}
\item \code{ab_p_demo__race_001___15}
\item \code{ab_p_demo__race_001___16}
\item \code{ab_p_demo__race_001___17}
\item \code{ab_p_demo__race_001___18}
\item \code{ab_p_demo__race_001___19}
\item \code{ab_p_demo__race_001___20}
\item \code{ab_p_demo__race_001___21}
\item \code{ab_p_demo__race_001___22}
\item \code{ab_p_demo__race_001___23}
\item \code{ab_p_demo__race_001___24}
\item \code{ab_p_demo__race_001___25}
\item \code{ab_p_demo__race_001___777}
\item \code{ab_p_demo__race_001___999}
\item \code{ab_p_demo__race_001__v01___999}
\item \code{ab_p_demo__race_001__v01___10}
\item \code{ab_p_demo__race_001__v01___11}
\item \code{ab_p_demo__race_001__v01___12}
\item \code{ab_p_demo__race_001__v01___20}
\item \code{ab_p_demo__race_001__v01___21}
\item \code{ab_p_demo__race_001__v01___22}
\item \code{ab_p_demo__race_001__v01___23}
\item \code{ab_p_demo__race_001__v01___13}
\item \code{ab_p_demo__race_001__v01___14}
\item \code{ab_p_demo__race_001__v01___15}
\item \code{ab_p_demo__race_001__v01___17}
\item \code{ab_p_demo__race_001__v01___18}
\item \code{ab_p_demo__race_001__v01___19}
\item \code{ab_p_demo__race_001__v01___16}
\item \code{ab_p_demo__race_001__v01___24}
\item \code{ab_p_demo__race_001__v01___777}
}
}
}
\keyword{datasets}
