% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh_aseba.R
\name{compute_mh_p_cbcl_sum}
\alias{compute_mh_p_cbcl_sum}
\title{Compute "Child Behavior Checklist [Parent] (Syndrome Scale): Sum"}
\usage{
compute_mh_p_cbcl_sum(
  data,
  name = "mh_p_cbcl_sum",
  max_na = 8,
  exclude = c("777", "999"),
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score column.}

\item{max_na}{numeric, positive whole number. Number of missing items
allowed. \code{NULL} means no limit.}

\item{exclude}{character vector. Values to be excluded from the summary score.}

\item{combine}{logical. If \code{TRUE} (default), the summary score is
is appended as a new column to the input data frame. If \code{FALSE}, the
summary score is returned as a separate one-column data frame.}
}
\value{
tbl. see \code{combine}.
}
\description{
Computes the summary score \code{mh_p_cbcl_sum}
Child Behavior Checklist [Parent] (Syndrome Scale): Sum
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{mh_p_cbcl__attn__adhd_001}
\item \code{mh_p_cbcl__attn__adhd_002}
\item \code{mh_p_cbcl__attn__adhd_003}
\item \code{mh_p_cbcl__aggr__adhd_001}
\item \code{mh_p_cbcl__attn__adhd_004}
\item \code{mh_p_cbcl__attn__adhd_005}
\item \code{mh_p_cbcl__othpr__adhd_001}
\item \code{mh_p_cbcl__soc__anx_001}
\item \code{mh_p_cbcl__anxdep__anx_007}
\item \code{mh_p_cbcl__anxdep__anx_001}
\item \code{mh_p_cbcl__anxdep__anx_002}
\item \code{mh_p_cbcl__anxdep__anx_003}
\item \code{mh_p_cbcl__anxdep__anx_004}
\item \code{mh_p_cbcl__som__anx_001}
\item \code{mh_p_cbcl__anxdep__anx_005}
\item \code{mh_p_cbcl__anxdep__anx_006}
\item \code{mh_p_cbcl__rule__cond_010}
\item \code{mh_p_cbcl__rule__cond_011}
\item \code{mh_p_cbcl__othpr__cond_001}
\item \code{mh_p_cbcl__aggr__cond_001}
\item \code{mh_p_cbcl__aggr__cond_002}
\item \code{mh_p_cbcl__rule__cond_001}
\item \code{mh_p_cbcl__rule__cond_002}
\item \code{mh_p_cbcl__aggr__cond_003}
\item \code{mh_p_cbcl__rule__cond_003}
\item \code{mh_p_cbcl__rule__cond_004}
\item \code{mh_p_cbcl__aggr__cond_004}
\item \code{mh_p_cbcl__rule__cond_005}
\item \code{mh_p_cbcl__rule__cond_006}
\item \code{mh_p_cbcl__rule__cond_007}
\item \code{mh_p_cbcl__rule__cond_008}
\item \code{mh_p_cbcl__rule__cond_009}
\item \code{mh_p_cbcl__aggr__cond_005}
\item \code{mh_p_cbcl__wthdep__dep_001}
\item \code{mh_p_cbcl__tho__dep_003}
\item \code{mh_p_cbcl__wthdep__dep_002}
\item \code{mh_p_cbcl__wthdep__dep_003}
\item \code{mh_p_cbcl__anxdep__dep_001}
\item \code{mh_p_cbcl__tho__dep_001}
\item \code{mh_p_cbcl__othpr__dep_001}
\item \code{mh_p_cbcl__anxdep__dep_002}
\item \code{mh_p_cbcl__anxdep__dep_003}
\item \code{mh_p_cbcl__som__dep_001}
\item \code{mh_p_cbcl__tho__dep_002}
\item \code{mh_p_cbcl__othpr__dep_002}
\item \code{mh_p_cbcl__anxdep__dep_004}
\item \code{mh_p_cbcl__aggr__opp_001}
\item \code{mh_p_cbcl__aggr__opp_002}
\item \code{mh_p_cbcl__aggr__opp_003}
\item \code{mh_p_cbcl__aggr__opp_004}
\item \code{mh_p_cbcl__aggr__opp_005}
\item \code{mh_p_cbcl__som__somat_001}
\item \code{mh_p_cbcl__som__somat_002}
\item \code{mh_p_cbcl__som__somat_003}
\item \code{mh_p_cbcl__som__somat_004}
\item \code{mh_p_cbcl__som__somat_005}
\item \code{mh_p_cbcl__som__somat_006}
\item \code{mh_p_cbcl__som__somat_007}
\item \code{mh_p_cbcl__tho_001}
\item \code{mh_p_cbcl__anxdep_001}
\item \code{mh_p_cbcl__tho_007}
\item \code{mh_p_cbcl__tho_010}
\item \code{mh_p_cbcl__tho_011}
\item \code{mh_p_cbcl__attn_002}
\item \code{mh_p_cbcl__attn_003}
\item \code{mh_p_cbcl__attn_005}
\item \code{mh_p_cbcl__wthdep_005}
\item \code{mh_p_cbcl__soc_004}
\item \code{mh_p_cbcl__wthdep_003}
\item \code{mh_p_cbcl__aggr_004}
\item \code{mh_p_cbcl__aggr_001}
\item \code{mh_p_cbcl__aggr_002}
\item \code{mh_p_cbcl__aggr_003}
\item \code{mh_p_cbcl__aggr_005}
\item \code{mh_p_cbcl__aggr_006}
\item \code{mh_p_cbcl__aggr_007}
\item \code{mh_p_cbcl__anxdep_002}
\item \code{mh_p_cbcl__attn_001}
\item \code{mh_p_cbcl__attn_004}
\item \code{mh_p_cbcl__rule_001}
\item \code{mh_p_cbcl__rule_006}
\item \code{mh_p_cbcl__rule_002}
\item \code{mh_p_cbcl__rule_003}
\item \code{mh_p_cbcl__rule_004}
\item \code{mh_p_cbcl__rule_005}
\item \code{mh_p_cbcl__wthdep_001}
\item \code{mh_p_cbcl__wthdep_002}
\item \code{mh_p_cbcl__wthdep_004}
\item \code{mh_p_cbcl__som_001}
\item \code{mh_p_cbcl__som_002}
\item \code{mh_p_cbcl__othpr_001}
\item \code{mh_p_cbcl__othpr_002}
\item \code{mh_p_cbcl__othpr_009}
\item \code{mh_p_cbcl__othpr_010}
\item \code{mh_p_cbcl__othpr_011}
\item \code{mh_p_cbcl__othpr_012}
\item \code{mh_p_cbcl__othpr_003}
\item \code{mh_p_cbcl__othpr_004}
\item \code{mh_p_cbcl__othpr_005}
\item \code{mh_p_cbcl__othpr_006}
\item \code{mh_p_cbcl__othpr_007}
\item \code{mh_p_cbcl__othpr_008}
\item \code{mh_p_cbcl__soc_001}
\item \code{mh_p_cbcl__soc_002}
\item \code{mh_p_cbcl__soc_003}
\item \code{mh_p_cbcl__soc_005}
\item \code{mh_p_cbcl__soc_006}
\item \code{mh_p_cbcl__soc_007}
\item \code{mh_p_cbcl__soc_008}
\item \code{mh_p_cbcl__soc_009}
\item \code{mh_p_cbcl__soc_010}
\item \code{mh_p_cbcl__tho_002}
\item \code{mh_p_cbcl__tho_003}
\item \code{mh_p_cbcl__tho_004}
\item \code{mh_p_cbcl__tho_005}
\item \code{mh_p_cbcl__tho_006}
\item \code{mh_p_cbcl__tho_008}
\item \code{mh_p_cbcl__tho_009}
\item \code{mh_p_cbcl__tho_012}
}
\item \emph{Excluded values:}
\itemize{
\item 777
\item 999
}
\item \emph{Validation criterion:} maximally 8 of 119 items missing
}
}
\examples{
\dontrun{
compute_mh_p_cbcl_sum(data) |>
  select(
    any_of(c("mh_p_cbcl_sum", vars_mh_p_cbcl))
  )
}
}
\seealso{
\code{\link[=compute_mh_p_cbcl_nm]{compute_mh_p_cbcl_nm()}}
}
