% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh.R
\docType{data}
\name{vars_mh_p_ple}
\alias{vars_mh_p_ple}
\alias{vars_mh_p_ple__exp}
\alias{compute_mh_p_ple_count}
\title{Compute "Life Events [Parent] (Events): Count"}
\format{
vars_mh_p_ple is a character vector of all column names
used to compute summary score of \code{mh_p_ple}.

vars_mh_p_ple__exp is a character vector of all column names
used to compute summary score of \code{mh_p_ple__exp}.
}
\usage{
vars_mh_p_ple

vars_mh_p_ple__exp

compute_mh_p_ple_count(
  data,
  name = "mh_p_ple_count",
  combine = TRUE,
  max_na = NULL
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the new column to be created (Default:
the name used in the ABCD data release).}

\item{combine}{logical. If TRUE, the new column will be bound to the input
data frame. If FALSE, the new column will be created as a new data frame.}

\item{max_na}{numeric, positive whole number. Number of missing items
allowed. \code{NULL} means no limit (Default: NULL).}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{mh_p_ple_count}
Life Events [Parent] (Events): Count
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{mh_p_ple_001}
\item \code{mh_p_ple_002}
\item \code{mh_p_ple_003}
\item \code{mh_p_ple_004}
\item \code{mh_p_ple_005}
\item \code{mh_p_ple_006}
\item \code{mh_p_ple_007}
\item \code{mh_p_ple_008}
\item \code{mh_p_ple_009}
\item \code{mh_p_ple_010}
\item \code{mh_p_ple_011}
\item \code{mh_p_ple_012}
\item \code{mh_p_ple_013}
\item \code{mh_p_ple_014}
\item \code{mh_p_ple_015}
\item \code{mh_p_ple_016}
\item \code{mh_p_ple_017}
\item \code{mh_p_ple_018}
\item \code{mh_p_ple_019}
\item \code{mh_p_ple_020}
\item \code{mh_p_ple_021}
\item \code{mh_p_ple_022}
\item \code{mh_p_ple_023}
\item \code{mh_p_ple_024}
\item \code{mh_p_ple_025}
}
\item \emph{Excluded values:}
\itemize{
\item 444
\item 777
\item 999
}
}
}
\keyword{datasets}
