% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_su.R
\name{compute_su_p_ksads__aud_all}
\alias{compute_su_p_ksads__aud_all}
\title{Compute all summary scores for su_p_ksads__aud}
\usage{
compute_su_p_ksads__aud_all(data)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}
}
\value{
tbl. The input data frame with the summary scores appended as new columns.
}
\description{
This function computes all summary scores for the su_p_ksads__aud table.
Make sure to have all necessary columns in the data frame.
}
