% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_su.R
\name{compute_su_y_alcexp_all}
\alias{compute_su_y_alcexp_all}
\title{Compute all the su_y_alcexp scores}
\usage{
compute_su_y_alcexp_all(data)
}
\arguments{
\item{data}{tbl, Dataframe containing the columns to be summarized.}
}
\value{
tbl. The input data frame with the summary scores appended as
new columns.
}
\description{
A single function to compute all scores in the above domain using
\strong{default} arguments.
}
\examples{
\dontrun{
compute_su_y_alcexp_all(data)
}
}
