% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_su.R
\docType{data}
\name{vars_su_y_nicvapeexp__neg}
\alias{vars_su_y_nicvapeexp__neg}
\alias{compute_su_y_nicvapeexp__neg_prsum}
\title{Compute "ENDS Expectancies [Youth] (Strength of negative expectancies):
Prorated sum"}
\format{
vars_su_y_nicvapeexp__neg is a character vector of all column names
used to compute summary score of \code{su_y_nicvapeexp__neg_prsum} and
\code{su_y_nicvapeexp__neg_nm}
}
\usage{
vars_su_y_nicvapeexp__neg

compute_su_y_nicvapeexp__neg_prsum(
  data,
  name = "su_y_nicvapeexp__neg_prsum",
  combine = TRUE,
  max_na = 2
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character, Name of the new column to be created. Default is
the name in description, but users can change it.}

\item{combine}{logical, If \code{TRUE} (default), the summary score will be appended to
the input data frame. If \code{FALSE}, the summary score for each participant
will be returned as a separate data frame. (Default: TRUE)}

\item{max_na}{numeric, positive whole number. Number of missing items
allowed (Default: 1).}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{su_y_nicvapeexp__neg_prsum}
ENDS Expectancies [Youth] (Strength of negative expectancies):
Prorated sum [Validation: No more than 2 missing or declined]
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{su_y_nicvapeexp__neg_001}
\item \code{su_y_nicvapeexp__neg_002}
\item \code{su_y_nicvapeexp__neg_003}
\item \code{su_y_nicvapeexp__neg_004}
}
\item \emph{Excluded values:} none
\item \emph{Validation criterion:} maximally 2 of 4 items missing
}
}
\keyword{datasets}
