% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{tlfb_config}
\alias{tlfb_config}
\title{Configuration for Timeline Followback calculations}
\format{
An object of class \code{tbl_df} (inherits from \code{tbl}, \code{data.frame}) with 906 rows and 10 columns.
}
\usage{
tlfb_config
}
\description{
Settings for processing TLFB substance use data.
}
\keyword{datasets}
\keyword{internal}
