% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_fc.R
\docType{data}
\name{vars_fc_y_eut__ethn}
\alias{vars_fc_y_eut__ethn}
\alias{compute_fc_y_eut__ethn_mean}
\title{Compute "Experiences with Unfair Treatment [Youth] (Ethnicity): Mean"}
\format{
vars_fc_y_eut__ethn is a character vector of all column names
used to compute summary score of \code{fc_y_eut__ethn}.
}
\usage{
vars_fc_y_eut__ethn

compute_fc_y_eut__ethn_mean(data, name = "fc_y_eut__ethn_mean", combine = TRUE)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score. Default is the name in
the description.}

\item{combine}{logical. If \code{TRUE}, the summary score is appended to the
input data frame. If \code{FALSE}, the summary score is returned as a separate
data frame. Default is \code{TRUE}.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{fc_y_eut__ethn_mean}
(Experiences with Unfair Treatment [Youth] (Ethnicity): Mean)
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{fc_y_eut__ethn_001a}
\item \code{fc_y_eut__ethn_001b}
\item \code{fc_y_eut__ethn_001c}/\code{fc_y_eut__ethn_001c__v01}
\item \code{fc_y_eut__ethn_001d} (only from event "ses-06A" onwards)
\item \code{fc_y_eut__ethn_002}
\item \code{fc_y_eut__ethn_003a}/\code{fc_y_eut__ethn_003a__v01}
\item \code{fc_y_eut__ethn_003b}/\code{fc_y_eut__ethn_003b__v01}
\item \code{fc_y_eut__ethn_003c}/\code{fc_y_eut__ethn_003c__v01}
}
\item \emph{Excluded values:}
\itemize{
\item 444
\item 777
\item 999
}
\item \emph{Validation criterion:}
\itemize{
\item before event ses-06A: none of 7 items missing
\item starting at event ses-06A: maximally 1 of 8 items missing
}
}
}
\keyword{datasets}
