% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_su.R
\name{compute_su_y_alchss_all}
\alias{compute_su_y_alchss_all}
\title{Compute all Alcohol Hangover Symptoms Scale (HSS) Youth summary scores}
\usage{
compute_su_y_alchss_all(data)
}
\arguments{
\item{data}{tbl, Dataframe containing the columns to be summarized.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
compute all summary scores of Alcohol Hangover Symptoms Scale (HSS) Youth
}
\examples{
\dontrun{
compute_su_y_alchss_all(data)
}
}
