% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_ph.R
\name{compute_ph_p_sds__dims_nm}
\alias{compute_ph_p_sds__dims_nm}
\title{Compute "Sleep Disturbance Scale [Parent] (Disorders of initiating and
maintaining sleep): Number missing"}
\usage{
compute_ph_p_sds__dims_nm(
  data,
  name = "ph_p_sds__dims_nm",
  exclude = c("777", "999"),
  combine = TRUE
)
}
\arguments{
\item{data}{tbl, Dataframe containing the columns to be summarized.}

\item{name}{character, Name of the new column to be created. Default is
the name in description, but users can change it.}

\item{exclude}{character, Values to be excluded from the summary score.}

\item{combine}{logical, If \code{TRUE}, the summary score will be appended to
the input data frame. If \code{FALSE}, the summary score will be returned as a
separate data frame.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{ph_p_sds__dims_nm}
Sleep Disturbance Scale [Parent] (Disorders of initiating and maintaining
sleep): Number missing
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{ph_p_sds__dims_001}
\item \code{ph_p_sds__dims_002}
\item \code{ph_p_sds__dims_003}
\item \code{ph_p_sds__dims_004}
\item \code{ph_p_sds__dims_005}
\item \code{ph_p_sds__dims_006}
\item \code{ph_p_sds__dims_007}
}
\item \emph{Excluded values:}
\itemize{
\item 777
\item 999
}
}
}
\seealso{
\code{\link[=compute_ph_p_sds__dims_sum]{compute_ph_p_sds__dims_sum()}}
}
