% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_ph.R
\docType{data}
\name{vars_ph_p_pds__f}
\alias{vars_ph_p_pds__f}
\alias{compute_ph_p_pds__f_mean}
\title{Compute "Pubertal Development Scale & Menstrual Cycle Survey History
[Parent] (Female): Mean"}
\format{
vars_ph_p_pds__f is a character vector of all column names
used to compute summary score of \code{ph_p_pds__f_mean} and
\code{ph_p_pds__f_nm}.
}
\usage{
vars_ph_p_pds__f

compute_ph_p_pds__f_mean(
  data,
  name = "ph_p_pds__f_mean",
  exclude = c("777", "999"),
  combine = TRUE,
  max_na = 1
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score column.}

\item{exclude}{character vector. Values to be excluded from the summary
score calculation.}

\item{combine}{logical. If \code{TRUE} (default), the summary score is
is appended as a new column to the input data frame. If \code{FALSE}, the
summary score is returned as a separate one-column data frame.}

\item{max_na}{numeric, positive whole number. Number of missing items
allowed. \code{NULL} means no limit.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{ph_p_pds__f_mean}
Pubertal Development Scale & Menstrual Cycle Survey History [Parent]
(Female): Mean [Validation: No more than 1 missing or declined]
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{ph_p_pds_001}
\item \code{ph_p_pds_002}
\item \code{ph_p_pds_003}
\item \code{ph_p_pds__f_001}
\item \code{ph_p_pds__f_002}
}
\item \emph{Excluded values:}
\itemize{
\item 777
\item 999
}
\item \emph{Validation criterion:} maximally 1 item missing
\item \emph{Notes:}
\itemize{
\item Values in \code{ph_p_pds__f_002} were recoded:
\itemize{
\item "0" --> "1",
\item "1" --> "4"
}
}
}
}
\keyword{datasets}
