% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_nt.R
\name{compute_nt_p_yst__pmum_nm}
\alias{compute_nt_p_yst__pmum_nm}
\title{Compute "Youth Screen Time [Parent] (Problematic Media Use): Number
missing"}
\usage{
compute_nt_p_yst__pmum_nm(data, name = "nt_p_yst__pmum_nm", combine = TRUE)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the new column to be created (Default:
the name used in the ABCD data release).}

\item{combine}{logical. If TRUE, the new column will be bound to the input
data frame. If FALSE, the new column will be created as a new data frame.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{nt_p_yst__pmum_nm}
Youth Screen Time [Parent] (Problematic Media Use): Number missing
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{nt_p_yst__pmum_001}
\item \code{nt_p_yst__pmum_002}
\item \code{nt_p_yst__pmum_003}
\item \code{nt_p_yst__pmum_004}
\item \code{nt_p_yst__pmum_005}
\item \code{nt_p_yst__pmum_006}
\item \code{nt_p_yst__pmum_007}
\item \code{nt_p_yst__pmum_008}
\item \code{nt_p_yst__pmum_009}
}
\item \emph{Excluded values:}
\itemize{
\item 777
\item 999
}
}
}
