% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_fc.R
\name{compute_fc_p_pk__knowl_nm}
\alias{compute_fc_p_pk__knowl_nm}
\title{Compute "Parental Knowledge Scale [Parent]: Number missing"}
\usage{
compute_fc_p_pk__knowl_nm(data, name = "fc_p_pk__knowl_nm", combine = TRUE)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score. Default is the name in
the description.}

\item{combine}{logical. If \code{TRUE}, the summary score is appended to the
input data frame. If \code{FALSE}, the summary score is returned as a separate
data frame. Default is \code{TRUE}.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{fc_p_pk__knowl_nm}
(Parental Knowledge Scale [Parent]: Number missing)
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{fc_p_pk__knowl_001}
\item \code{fc_p_pk__knowl_002}
\item \code{fc_p_pk__knowl_003}
\item \code{fc_p_pk__knowl_004}
\item \code{fc_p_pk__knowl_005}
\item \code{fc_p_pk__knowl_006}
\item \code{fc_p_pk__knowl_007}
\item \code{fc_p_pk__knowl_008}
\item \code{fc_p_pk__knowl_009}
}
\item \emph{Excluded values:}
\itemize{
\item 777
}
}
}
\seealso{
\code{\link[=compute_fc_p_pk__knowl_mean]{compute_fc_p_pk__knowl_mean()}}
}
