% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_ph.R
\docType{data}
\name{vars_ph_y_bp__sys}
\alias{vars_ph_y_bp__sys}
\alias{compute_ph_y_bp__sys_mean}
\title{Compute "Blood Pressure [Youth] (Systolic): Mean"}
\format{
vars_ph_y_bp__sys is a character vector of all column names
used to compute summary scores of \code{ph_y_bp__sys}.
}
\usage{
vars_ph_y_bp__sys

compute_ph_y_bp__sys_mean(data, name = "ph_y_bp__sys_mean", combine = TRUE)
}
\arguments{
\item{data}{tbl, Dataframe containing the columns to be summarized.}

\item{name}{character, Name of the new column to be created. Default is
the name in description, but users can change it.}

\item{combine}{logical, If \code{TRUE}, the summary score will be appended to
the input data frame. If \code{FALSE}, the summary score will be returned as a
separate data frame.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{ph_y_bp__sys_mean}
Blood Pressure [Youth] (Systolic): Mean
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{ph_y_bp__sys__r01_001}
\item \code{ph_y_bp__sys__r01_002}
\item \code{ph_y_bp__sys__r01_003}
\item \code{ph_y_bp__sys__r02_001}
\item \code{ph_y_bp__sys__r02_002}
\item \code{ph_y_bp__sys__r03_001}
\item \code{ph_y_bp__sys__r03_002}
}
\item \emph{Excluded values:} none
}
}
\examples{
\dontrun{
compute_ph_y_bp__sys_mean(data) |>
  select(
    all_of(c("ph_y_bp__sys_mean", vars_ph_y_bp__sys))
  )
}
}
\keyword{datasets}
