% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_nt_fitbit.R
\name{compute_fitbit_score_steps}
\alias{compute_fitbit_score_steps}
\title{Computes steps summary scores by day or by specified time bins}
\usage{
compute_fitbit_score_steps(
  data_exclusions,
  bin_minutes = 1440,
  data_daily_qc,
  qc_threshold,
  append_daily_fitbit_qc = FALSE
)
}
\arguments{
\item{data_exclusions}{tbl. Data frame with \code{hrate_excluded} flag.}

\item{bin_minutes}{numeric, positive whole number. Number of minutes to bin
data by.}

\item{data_daily_qc}{tbl. Data frame with Fitbit provided daily step count.}

\item{qc_threshold}{numeric, between 0 and 1. Minimum percentage of Fitbit
step count that must be met by computed active step count for QC to pass.}

\item{append_daily_fitbit_qc}{logical. If TRUE, appends daily Fitbit step
count and QC results to output (Default: FALSE). If TRUE, \code{data_daily_qc}
and \code{qc_threshold} must be provided and \code{bin_minutes} must be NULL.}
}
\value{
tbl. The input data frame with the following additional columns:
\itemize{
\item \code{start}: If non-daily bin selected (i.e. != 1440 minutes), start time
stamp of bin.
\item \code{end}:  If non-daily bin selected (i.e., != 1440 minutes), end time stamp
of the bin.
\item \code{steps_total}: Total steps after excluding minutes with invalid heart
rate.
\item \code{steps_actv}: Total steps during non-sleep, non-excluded minutes.
\item \code{steps}: Total steps, regardless of heart rate exclusions.
\item \code{steps_fitb}:
\item \code{prct_steps_fitb}: percent accordance between steps_actv and Fitbit
calculated daily step count, if append_daily_fitbit_qc = TRUE.
\item \code{qc_steps}: percent accordance between steps_actv and Fitbit calculated
daily step count >= selected qc_threshold.
}

@note
\itemize{
\item data_exclusions input: output of identify_hr_exclusions() or
identify_hr_recovery(); needs exclusion flags
\item data_daily_qc input: fitbit_raw_metrics raw dataset
}
}
\description{
Computes steps summary scores by day or by specified time bins (e.g.,
15-min, 30-min, 60-min), with optional integration of daily step count QC
from raw metrics.
}
\keyword{internal}
