% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh.R
\name{dummy_mh}
\alias{dummy_mh}
\title{Dummy function for all MH summary score functions.}
\usage{
dummy_mh(data, name, max_na, combine, exclude, event, events)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score column.}

\item{max_na}{numeric, positive whole number. Number of missing items
allowed. \code{NULL} means no limit.}

\item{combine}{logical. If \code{TRUE} (default), the summary score is
is appended as a new column to the input data frame. If \code{FALSE}, the
summary score is returned as a separate one-column data frame.}

\item{exclude}{character vector. Values to be excluded from the summary
score calculation.}

\item{event}{character. Event (session ID) to be used.}

\item{events}{character vector. Event (session ID) to be used.}
}
\value{
tbl. see \code{combine}.
}
\description{
Dummy function for all MH summary score functions.
}
\keyword{internal}
