% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_ph.R
\name{compute_ph_y_pds__f_nm}
\alias{compute_ph_y_pds__f_nm}
\title{Compute "Pubertal Development Scale & Menstrual Cycle Survey History
[Youth] (Female): Number missing"}
\usage{
compute_ph_y_pds__f_nm(
  data,
  name = "ph_y_pds__f_nm",
  exclude = c("777", "999"),
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score column.}

\item{exclude}{character vector. Values to be excluded from the summary
score calculation.}

\item{combine}{logical. If \code{TRUE} (default), the summary score is
is appended as a new column to the input data frame. If \code{FALSE}, the
summary score is returned as a separate one-column data frame.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{ph_y_pds__f_nm}
Pubertal Development Scale & Menstrual Cycle Survey History [Youth]
(Female): Number missing
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{ph_y_pds_001}
\item \code{ph_y_pds_002}
\item \code{ph_y_pds_003}
\item \code{ph_y_pds__f_001}
\item \code{ph_y_pds__f_002}
}
\item \emph{Excluded values:}
\itemize{
\item 777
\item 999
}
}
}
\seealso{
\code{\link[=compute_ph_y_pds__f_mean]{compute_ph_y_pds__f_mean()}}
}
