% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh_famhx.R
\docType{data}
\name{vars_mh_p_famhx__nerve__moth__fath_indicator}
\alias{vars_mh_p_famhx__nerve__moth__fath_indicator}
\alias{compute_mh_p_famhx__nerve__moth__fath_indicator}
\title{Compute "Family History [Parent] (Nerves/Nervous Breakdown) Endorsed:
Either parent"}
\format{
a character vector of fields used to compute
\code{mh_p_famhx__nerve__moth__fath_indicator}.
}
\usage{
vars_mh_p_famhx__nerve__moth__fath_indicator

compute_mh_p_famhx__nerve__moth__fath_indicator(
  data,
  name = "mh_p_famhx__nerve__moth__fath_indicator",
  exclude = c("777", "888", "999"),
  combine = TRUE
)
}
\arguments{
\item{data}{tibble. A data frame containing the data.}

\item{name}{character. The name of the output column for the computed score.}

\item{exclude}{character vector. Values to be excluded from the summary
score calculation.}

\item{combine}{logical. Whether to combine the summary score column with the
input data frame (Default: \code{TRUE}).}
}
\value{
tbl. The input data frame with the summary score appended as a new
column.
}
\description{
Computes the summary score \code{mh_p_famhx__nerve__moth__fath_indicator}
(Family History [Parent] (Nerves/Nervous Breakdown) Endorsed:
Either parent)
\itemize{
\item \emph{Excluded values:}
\itemize{
\item 777
\item 888
\item 999
}
\item \emph{Notes:}
\itemize{
\item Following logic is applied to compute the score:
\itemize{
\item father endorsed \code{yes} OR mother endorsed \code{yes}  = \code{1}
\item father endorsed \code{no} AND mother endorsed \code{no}   = \code{0}
\item all other cases set to \code{NA}
}
}
}
}
\keyword{datasets}
