% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_fc.R
\docType{data}
\name{vars_fc_p_nsc__ns}
\alias{vars_fc_p_nsc__ns}
\alias{compute_fc_p_nsc__ns_mean}
\title{Compute "Neighborhood Safety & Crime [Parent] (Neighborhood safety): Mean"}
\format{
vars_fc_p_nsc__ns is a character vector of all column names
used to compute summary score of \code{fc_p_nsc__ns}.
}
\usage{
vars_fc_p_nsc__ns

compute_fc_p_nsc__ns_mean(
  data,
  name = "fc_p_nsc__ns_mean",
  max_na = 0,
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score. Default is the name in
the description.}

\item{max_na}{numeric, positive whole number. Number of missing items
allowed (Default: 0).}

\item{combine}{logical. If \code{TRUE}, the summary score is appended to the
input data frame. If \code{FALSE}, the summary score is returned as a separate
data frame. Default is \code{TRUE}.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{fc_p_nsc__ns_mean}
(Neighborhood Safety & Crime [Parent] (Neighborhood safety): Mean)
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{fc_p_nsc__ns_001}
\item \code{fc_p_nsc__ns_002}
\item \code{fc_p_nsc__ns_003}
}
\item \emph{Excluded values:}
\itemize{
\item 777
\item 999
}
\item \emph{Validation criterion:} none of 3 items missing
}
}
\keyword{datasets}
