% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ABCDscores-package.R
\docType{package}
\name{ABCDscores-package}
\alias{ABCDscores}
\alias{ABCDscores-package}
\title{ABCDscores: Summary Scores of the Adolescent Brain Cognitive Development (ABCD) Study}
\description{
Provides functions to compute summary scores (besides proprietary ones) reported in the tabulated data resource that is released by the Adolescent Brain Cognitive Development (ABCD) study.
}
\references{
Zhang, L., Celhay, O., Das, B., Berman, S., Ziemer, L. R., Smith, C. J., Dale, A. M., & Linkersdörfer, J. (2025).
ABCDscores: An R package for computing summary scores in the ABCD Study. \emph{bioRxiv}. \doi{10.1101/2025.09.04.674066}
}
\seealso{
Useful links:
\itemize{
  \item \url{https://software.nbdc-datahub.org/ABCDscores/}
}

}
\author{
\strong{Maintainer}: Le Zhang \email{dairc.service@gmail.com} (\href{https://orcid.org/0009-0008-0205-2150}{ORCID})

Authors:
\itemize{
  \item Janosch Linkersdoerfer \email{linkersdoerfer@gmail.com} (\href{https://orcid.org/0000-0002-1577-1233}{ORCID})
  \item Olivier Celhay \email{olivier.celhay@gmail.com} (\href{https://orcid.org/0000-0002-2971-9110}{ORCID})
  \item Biplabendu Das \email{biplabendu.das@gmail.com} (\href{https://orcid.org/0000-0003-0855-262X}{ORCID})
  \item Sammy Berman \email{sammyberman@gmail.com} (\href{https://orcid.org/0000-0002-9803-019X}{ORCID})
  \item Laura Ziemer \email{lrziemer@gmail.com} (\href{https://orcid.org/0000-0003-0026-3823}{ORCID})
  \item Shermaine Abad \email{shermaineabad@gmail.com} (\href{https://orcid.org/0009-0009-6013-9147}{ORCID})
}

}
\keyword{internal}
