% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh.R
\name{compute_mh_y_ppsss__dist__pers_count}
\alias{compute_mh_y_ppsss__dist__pers_count}
\title{Compute "Prodromal Psychosis Scale [Youth] (Persistent Distress Count)"}
\usage{
compute_mh_y_ppsss__dist__pers_count(
  data,
  name = "mh_y_ppsss__dist__pers_count"
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score column.}
}
\value{
a tibble of the \code{participant_id} column and the new static column
}
\description{
Computes the summary score \code{mh_y_ppsss__dist__pers_count}
Prodromal Psychosis Scale [Youth] (Persistent Distress Count):
Number of times criteria met

This function creates a static variable from longitudinal data.
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item mh_y_pps__dist__pers_score (intermediate score)
}
\item \emph{Excluded values:} none
\item \emph{Validation criterion:} none
}
}
\seealso{
\code{\link[=compute_mh_y_pps__dist__pers_score]{compute_mh_y_pps__dist__pers_score()}}
}
