% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_nt.R
\name{compute_nt_y_stq__screen__wknd_nm}
\alias{compute_nt_y_stq__screen__wknd_nm}
\title{Compute "Screen Time [Youth] (Weekend): Number missing"}
\usage{
compute_nt_y_stq__screen__wknd_nm(
  data,
  name = "nt_y_stq__screen__wknd_nm",
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the new column to be created (Default:
the name used in the ABCD data release).}

\item{combine}{logical. If TRUE, the new column will be bound to the input
data frame. If FALSE, the new column will be created as a new data frame.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{nt_y_stq__screen__wknd_nm}
Screen Time [Youth] (Weekend): Number missing
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{nt_y_stq__screen__wknd_001}
\item \code{nt_y_stq__screen__wknd_002}
\item \code{nt_y_stq__screen__wknd_003}
\item \code{nt_y_stq__screen__wknd_004}
\item \code{nt_y_stq__screen__wknd_005}
\item \code{nt_y_stq__screen__wknd_006}
\item \code{nt_y_stq__screen__wknd__hr_001}
\item \code{nt_y_stq__screen__wknd__min_001}
\item \code{nt_y_stq__screen__wknd__hr_001__v01}
\item \code{nt_y_stq__screen__wknd__min_001__v01}
\item \code{nt_y_stq__screen__wknd__hr_002}
\item \code{nt_y_stq__screen__wknd__min_002}
\item \code{nt_y_stq__screen__wknd__hr_003}
\item \code{nt_y_stq__screen__wknd__min_003}
\item \code{nt_y_stq__screen__wknd__hr_004}
\item \code{nt_y_stq__screen__wknd__min_004}
\item \code{nt_y_stq__screen__wknd__hr_005}
\item \code{nt_y_stq__screen__wknd__min_005}
\item \code{nt_y_stq__screen__wknd__hr_006}
\item \code{nt_y_stq__screen__wknd__min_006}
\item \code{nt_y_stq__screen__wknd__hr_007}
\item \code{nt_y_stq__screen__wknd__min_007}
\item \code{nt_y_stq__screen__wknd__hr_008}
\item \code{nt_y_stq__screen__wknd__min_008}
\item \code{nt_y_stq__screen__wknd__hr_009}
\item \code{nt_y_stq__screen__wknd__min_009}
}
\item \emph{Excluded values:}
\itemize{
\item 777
\item 999
}
}
}
