% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_su.R
\name{compute_su_y_alcsre__hvy_nm}
\alias{compute_su_y_alcsre__hvy_nm}
\title{Compute "Alcohol Subject Response and Effects [Youth] (Heaviest drinking
period): Number missing"}
\usage{
compute_su_y_alcsre__hvy_nm(data, name = "su_y_alcsre__hvy_nm", combine = TRUE)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the new column to be created (Default:
the name used in the ABCD data release).}

\item{combine}{logical. If TRUE, the new column will be bound to the input
data frame. If FALSE, the new column will be created as a new data frame.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{su_y_alcsre__hvy_nm}
Alcohol Subject Response and Effects [Youth] (Heaviest drinking
period): Number missing
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{su_y_alcsre__hvy_001}
\item \code{su_y_alcsre__hvy_002}
\item \code{su_y_alcsre__hvy_003}
\item \code{su_y_alcsre__hvy_004}
}
\item \emph{Excluded values:} none
}
}
