% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh.R
\name{compute_mh_p_ders__distract_nm}
\alias{compute_mh_p_ders__distract_nm}
\title{Compute "Difficulties in Emotion Regulation Scale [Parent] (Distracted):
Number missing"}
\usage{
compute_mh_p_ders__distract_nm(
  data,
  name = "mh_p_ders__distract_nm",
  exclude = c("999", "777"),
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score column.}

\item{exclude}{character vector. Values to be excluded from the summary
score calculation.}

\item{combine}{logical. If \code{TRUE} (default), the summary score is
is appended as a new column to the input data frame. If \code{FALSE}, the
summary score is returned as a separate one-column data frame.}
}
\value{
tbl. see \code{combine}.
}
\description{
Computes the summary score \code{mh_p_ders__distract_nm}
Difficulties in Emotion Regulation Scale [Parent] (Distracted): Number
missing
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{mh_p_ders__distract_001}
\item \code{mh_p_ders__distract_002}
\item \code{mh_p_ders__distract_003}
\item \code{mh_p_ders__distract_004}
}
\item \emph{Excluded values:}
\itemize{
\item 999
\item 777
}
}
}
\examples{
\dontrun{
compute_mh_p_ders__distract_nm(data) |>
  select(
    any_of(c("mh_p_ders__distract_nm", vars_mh_p_ders__distract))
  )
}
}
\seealso{
\code{\link[=compute_mh_p_ders__distract_mean]{compute_mh_p_ders__distract_mean()}}
}
