% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh.R
\name{compute_mh_y_pps__dist__curr_score}
\alias{compute_mh_y_pps__dist__curr_score}
\title{Compute "Prodromal Psychosis Scale [Youth] (Current Distress Score)"}
\usage{
compute_mh_y_pps__dist__curr_score(
  data,
  name = "mh_y_pps__dist__curr_score",
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score column.}

\item{combine}{logical. If \code{TRUE} (default), the summary score is
is appended as a new column to the input data frame. If \code{FALSE}, the
summary score is returned as a separate one-column data frame.}
}
\value{
tbl. see \code{combine}.
}
\description{
Computes the summary score \code{mh_y_pps__dist__curr_score}
Prodromal Psychosis Scale [Youth] (Current Distress Score)

For the current wave, if z-score of \code{mh_y_pps__severity_score} normalized
across all current participants in the assessment wave is >= 1.96, set the
value to "1"; else set the value to "0". If there is no score for the current
assessment wave,set the value to \code{NA} (missing).
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item mh_y_pps__severity_score (intermediate score)
}
\item \emph{Excluded values:} none
\item \emph{Validation criterion:}  none
}
}
\seealso{
\code{\link[=compute_mh_y_pps__severity_score]{compute_mh_y_pps__severity_score()}}
}
