% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh.R
\docType{data}
\name{vars_mh_y_sup}
\alias{vars_mh_y_sup}
\alias{compute_mh_y_sup_nm}
\title{Compute "7-Up Mania Inventory [Youth]: Number missing"}
\format{
\code{vars_mh_y_sup} is vector of all column names
used to compute summary score of \code{mh_y_sup} scores.
}
\usage{
vars_mh_y_sup

compute_mh_y_sup_nm(data, name = "mh_y_sup_nm", exclude = NULL, combine = TRUE)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score column.}

\item{exclude}{character vector. Values to be excluded from the summary
score calculation.}

\item{combine}{logical. If \code{TRUE} (default), the summary score is
is appended as a new column to the input data frame. If \code{FALSE}, the
summary score is returned as a separate one-column data frame.}
}
\value{
tbl. see \code{combine}.
}
\description{
Computes the summary score \code{mh_y_sup_nm}
7-Up Mania Inventory [Youth]: Number missing
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{mh_y_sup_001}
\item \code{mh_y_sup_002}
\item \code{mh_y_sup_003}
\item \code{mh_y_sup_004}
\item \code{mh_y_sup_005}
\item \code{mh_y_sup_006}
\item \code{mh_y_sup_007}
}
\item \emph{Excluded values:} none
}
}
\examples{
\dontrun{
compute_mh_y_sup_nm(data) |>
  select(
    any_of(c("mh_y_sup_nm", vars_mh_y_sup))
  )
}
}
\keyword{datasets}
