% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_su.R
\name{compute_su_y_mjsre_nm}
\alias{compute_su_y_mjsre_nm}
\title{Compute "Marijuana Subjective Response and Effects [Youth] (NA): Number
missing"}
\usage{
compute_su_y_mjsre_nm(data, name = "su_y_mjsre_nm", combine = TRUE)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the new column to be created (Default:
the name used in the ABCD data release).}

\item{combine}{logical. If TRUE, the new column will be bound to the input
data frame. If FALSE, the new column will be created as a new data frame.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{su_y_mjsre_nm}
Marijuana Subjective Response and Effects [Youth] (NA): Number missing
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{su_y_mjsre__pos_001}
\item \code{su_y_mjsre__pos_002}
\item \code{su_y_mjsre__pos_003}
\item \code{su_y_mjsre__neg_001}
\item \code{su_y_mjsre__neg_002}
\item \code{su_y_mjsre__neg_003}
\item \code{su_y_mjsre__neg_004}
\item \code{su_y_mjsre__neg_005}
\item \code{su_y_mjsre__neg_006}
\item \code{su_y_mjsre__neg_007}
\item \code{su_y_mjsre__neg_008}
}
\item \emph{Excluded values:} none
}
}
