% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_su.R
\docType{data}
\name{vars_su_y_alcexp__pos}
\alias{vars_su_y_alcexp__pos}
\alias{compute_su_y_alcexp__pos_prsum}
\title{Compute "Alcohol Expectancies (AEQ-AB) [Youth] (Strength of positive
expectancies): Prorated sum"}
\format{
vars_su_y_alcexp__pos is a character vector of all column names
used to compute summary score of \code{su_y_alcexp__pos_prsum} and
\code{su_y_alcexp__pos_nm}.
}
\usage{
vars_su_y_alcexp__pos

compute_su_y_alcexp__pos_prsum(
  data,
  name = "su_y_alcexp__pos_prsum",
  combine = TRUE,
  max_na = 1
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character, Name of the new column to be created. Default is
the name in description, but users can change it.}

\item{combine}{logical, If \code{TRUE} (default), the summary score will be appended to
the input data frame. If \code{FALSE}, the summary score for each participant
will be returned as a separate data frame. (Default: TRUE)}

\item{max_na}{numeric, positive whole number. Number of missing items
allowed (Default: 1).}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{su_y_alcexp__pos_prsum}
Alcohol Expectancies (AEQ-AB) [Youth] (Strength of positive
expectancies): Prorated sum
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{su_y_alcexp__pos_001}
\item \code{su_y_alcexp__pos_002}
\item \code{su_y_alcexp__pos_003}
}
\item \emph{Excluded values:} none
\item \emph{Validation criterion:} maximally 1 of 3 items missing
}
}
\keyword{datasets}
