% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_nt_fitbit.R
\name{compute_fitbit_activity_table_ext}
\alias{compute_fitbit_activity_table_ext}
\title{Computes extended daily activity summaries}
\usage{
compute_fitbit_activity_table_ext(
  data_activity,
  data_daily = NULL,
  hr_low = 50,
  hr_high = NULL,
  hr_rep_day = 10,
  hr_rep_sleep = 30,
  bin_minutes = 1440,
  append_daily_fitbit_qc = TRUE,
  qc_threshold = 0.8,
  offset = "12:00",
  min_actv_minutes,
  main_duration,
  gap = 90
)
}
\arguments{
\item{data_activity}{tbl. Data frame with activity data.}

\item{data_daily}{tbl. Data frame with daily Fitbit summary data.}

\item{hr_low}{numeric. Lower bound threshold for valid heart rate values.}

\item{hr_high}{numeric or NULL. Optional upper bound threshold.}

\item{hr_rep_day}{numeric. Threshold for identifying repeated HR.}

\item{hr_rep_sleep}{numeric. Threshold for identifying repeated HR.}

\item{bin_minutes}{numeric. Number of minutes used to bin data.}

\item{append_daily_fitbit_qc}{logical. If TRUE, add Fitbit-provided steps.}

\item{qc_threshold}{numeric, between 0 and 1. Minimum percentage of Fitbit
step count that must be met by computed active step count for QC to pass.}

\item{offset}{character. Time of day (HH:MM) cutoff.}

\item{min_actv_minutes}{numeric. Minimum number of active minutes required
for a day to pass quality control. Used to create a \code{{qc_Xmin}} flag
column in the output.}

\item{main_duration}{numeric. Minimum duration in minutes.}

\item{gap}{numeric. Maximum allowed gap.}
}
\value{
tbl. A daily-level extended activity summary.
}
\description{
Computes all daily activity scores (extended).
}
\note{
\itemize{
\item \code{data_activity}: fitbit_raw_activity or fitbit_covid_raw_activity
\item \code{data_daily}: fitbit_raw_metrics or fitbit_covid_raw_metrics
}
}
\seealso{
\code{\link[=compute_fitbit_activity_table]{compute_fitbit_activity_table()}}
}
