% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_su.R
\name{compute_su_y_prob_all}
\alias{compute_su_y_prob_all}
\title{Compute all the SU youth prob scores}
\usage{
compute_su_y_prob_all(data)
}
\arguments{
\item{data}{tbl, Dataframe containing the columns to be summarized.}
}
\value{
tbl. The input data frame with the summary scores appended as
new columns.
}
\description{
A single function to compute all PROB scores in SU domain.
}
\keyword{internal}
