% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_su.R
\name{compute_su_y_cigexp__neg_nm}
\alias{compute_su_y_cigexp__neg_nm}
\title{Compute "Cigarette Expectancies (ASCQ) [Youth] (Strength of negative
expectancies): Number missing"}
\usage{
compute_su_y_cigexp__neg_nm(data, name = "su_y_cigexp__neg_nm", combine = TRUE)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character, Name of the new column to be created. Default is
the name in description, but users can change it.}

\item{combine}{logical, If \code{TRUE} (default), the summary score will be appended to
the input data frame. If \code{FALSE}, the summary score for each participant
will be returned as a separate data frame. (Default: TRUE)}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{su_y_cigexp__neg_nm}
Cigarette Expectancies (ASCQ) [Youth] (Strength of negative
expectancies): Number missing
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{su_y_cigexp__neg_001}
\item \code{su_y_cigexp__neg_002}
}
\item \emph{Excluded values:} none
}
}
\seealso{
\code{\link[=compute_su_y_cigexp__neg_prsum]{compute_su_y_cigexp__neg_prsum()}}
}
