% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_fc.R
\docType{data}
\name{vars_fc_y_rpi}
\alias{vars_fc_y_rpi}
\alias{compute_fc_y_rpi_mean}
\title{Compute "Resistance to Peer Influence [Youth]: Mean"}
\format{
vars_fc_y_rpi is a character vector of all column names
used to compute summary score of \code{fc_y_rpi}.
}
\usage{
vars_fc_y_rpi

compute_fc_y_rpi_mean(data, name = "fc_y_rpi_mean", max_na = 3, combine = TRUE)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score. Default is the name in
the description.}

\item{max_na}{numeric, positive whole number. Number of missing items
allowed (Default: 3).}

\item{combine}{logical. If \code{TRUE}, the summary score is appended to the
input data frame. If \code{FALSE}, the summary score is returned as a separate
data frame. Default is \code{TRUE}.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{fc_y_rpi_mean}
(Resistance to Peer Influence [Youth]: Mean)
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{fc_y_rpi_001}
\item \code{fc_y_rpi_002}
\item \code{fc_y_rpi_003}
\item \code{fc_y_rpi_004}
\item \code{fc_y_rpi_005}
\item \code{fc_y_rpi_006}
\item \code{fc_y_rpi_007}
\item \code{fc_y_rpi_008}
\item \code{fc_y_rpi_009}
\item \code{fc_y_rpi_010}
}
\item \emph{Excluded values:} none
\item \emph{Validation criterion:} maximally 3 of 10 items missing
\item \emph{Note:} The following variables are reverse coded before computing the
summary score:
\itemize{
\item \code{fc_y_rpi_002}
\item \code{fc_y_rpi_006}
\item \code{fc_y_rpi_010}
}
}
}
\keyword{datasets}
