% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_su.R
\docType{data}
\name{vars_su_y_ksads__dud__hall__past__sx_mean}
\alias{vars_su_y_ksads__dud__hall__past__sx_mean}
\alias{compute_su_y_ksads__dud__hall__past__sx_mean}
\title{Compute "KSADS - Drug Use Disorders [Youth]
(Symptom: Hallucinogen - Past): Mean"}
\format{
vars_su_y_ksads__dud__hall__past__sx_mean is a character vector
of all column names used to compute summary score of
\code{su_y_ksads__dud__hall__past__sx_mean}
}
\usage{
vars_su_y_ksads__dud__hall__past__sx_mean

compute_su_y_ksads__dud__hall__past__sx_mean(
  data,
  name = "su_y_ksads__dud__hall__past__sx_mean",
  max_na = 3,
  exclude = c("555"),
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score column.}

\item{max_na}{numeric, positive whole number. Number of missing items
allowed. \code{NULL} means no limit.}

\item{exclude}{character vector. Values to be excluded from the summary
score calculation.}

\item{combine}{logical. If \code{TRUE} (default), the summary score is
is appended as a new column to the input data frame. If \code{FALSE}, the
summary score is returned as a separate one-column data frame.}
}
\value{
tbl. see \code{combine}.
}
\description{
Computes the summary score \code{su_y_ksads__dud__hall__past__sx_mean}
KSADS - Drug Use Disorders [Youth] (Symptom: Hallucinogen - Past): Mean
[Validation: No more than 3 missing or declined]
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{su_y_ksads__dud__actvdecr__hall__past_sx}
\item \code{su_y_ksads__dud__crave__hall__past_sx}
\item \code{su_y_ksads__dud__dwi__hall__past_sx}
\item \code{su_y_ksads__dud__failrespons__hall__past_sx}
\item \code{su_y_ksads__dud__haz__hall__past_sx}
\item \code{su_y_ksads__dud__negimpct__interprs__hall__past_sx}
\item \code{su_y_ksads__dud__negimpct__obl__hall__past_sx}
\item \code{su_y_ksads__dud__overuse__hall__past_sx}
\item \code{su_y_ksads__dud__prob__phys__hall__past_sx}
\item \code{su_y_ksads__dud__prob__psych__hall__past_sx}
\item \code{su_y_ksads__dud__reduce__dsr__hall__past_sx}
\item \code{su_y_ksads__dud__reduce__unsucces__hall__past_sx}
\item \code{su_y_ksads__dud__time__hall__past_sx}
\item \code{su_y_ksads__dud__tol__hall__past_sx}
\item \code{su_y_ksads__dud__withdr__hall__past_sx}
}
\item \emph{Excluded values:}
\itemize{
\item 555
}
\item \emph{Validation criterion:} maximally 3 of 15 items missing
}
}
\details{
KSADS summary scores are mostly calculating the means over variables,
but there are two special codes to handle:
\itemize{
\item \code{"888"}: item skipped by branching. When at least one input value is
observed, any \code{888} value is converted to "0" prior to averaging.
\item \code{"555"}: module not administered. If any input variable is "555"
leave the score as \code{NA}.
\item \code{NA}: missing value. If at least one input value is observed,
any \code{NA} values are converted to "0" prior to averaging.
If all inputs are \code{NA}, the summary score remains \code{NA}.
}
}
\keyword{datasets}
