% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh.R
\docType{data}
\name{vars_mh_y_upps__sens}
\alias{vars_mh_y_upps__sens}
\alias{compute_mh_y_upps__sens_nm}
\title{Compute "Urgency, Premeditation, Perseverance, Sensation Seeking, Positive
Urgency, Impulsive Behavior Scale (Short Version) [Youth] (Sensation
Seeking): Number missing"}
\format{
\code{vars_mh_y_upps__sens} is vector of all column names
used to compute summary score of \code{mh_y_upps__sens} scores.
}
\usage{
vars_mh_y_upps__sens

compute_mh_y_upps__sens_nm(
  data,
  name = "mh_y_upps__sens_nm",
  exclude = NULL,
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score column.}

\item{exclude}{character vector. Values to be excluded from the summary
score calculation.}

\item{combine}{logical. If \code{TRUE} (default), the summary score is
is appended as a new column to the input data frame. If \code{FALSE}, the
summary score is returned as a separate one-column data frame.}
}
\value{
tbl. see \code{combine}.
}
\description{
Computes the summary score \code{mh_y_upps__sens_nm}
Urgency, Premeditation, Perseverance, Sensation Seeking, Positive
Urgency, Impulsive Behavior Scale (Short Version) [Youth] (Sensation
Seeking): Number missing
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{mh_y_upps__sens_001}
\item \code{mh_y_upps__sens_002}
\item \code{mh_y_upps__sens_003}
\item \code{mh_y_upps__sens_004}
}
\item \emph{Excluded values:} none
}
}
\examples{
\dontrun{
compute_mh_y_upps__sens_nm(data) |>
  select(
    any_of(c("mh_y_upps__sens_nm", vars_mh_y_upps__sens))
  )
}
}
\keyword{datasets}
