% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh.R
\name{compute_mh_y_pps_nm}
\alias{compute_mh_y_pps_nm}
\title{Compute "Prodromal Psychosis Scale [Youth] (number of responses): Number
missing "}
\usage{
compute_mh_y_pps_nm(data, name = "mh_y_pps_nm", combine = TRUE)
}
\arguments{
\item{data}{tbl, Dataframe containing the columns to be summarized.}

\item{name}{character, Name of the new column to be created. Default is
the name in description, but users can change it.}

\item{combine}{logical, If \code{TRUE}, the summary score will be appended to
the input data frame. If \code{FALSE}, the summary score will be returned as a
separate data frame.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{mh_y_pps_nm}
Prodromal Psychosis Scale [Youth] (number of responses): Number
missing
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{mh_y_pps_001}
\item \code{mh_y_pps_002}
\item \code{mh_y_pps_003}
\item \code{mh_y_pps_004}
\item \code{mh_y_pps_005}
\item \code{mh_y_pps_006}
\item \code{mh_y_pps_007}
\item \code{mh_y_pps_008}
\item \code{mh_y_pps_009}
\item \code{mh_y_pps_010}
\item \code{mh_y_pps_011}
\item \code{mh_y_pps_012}
\item \code{mh_y_pps_013}
\item \code{mh_y_pps_014}
\item \code{mh_y_pps_015}
\item \code{mh_y_pps_016}
\item \code{mh_y_pps_017}
\item \code{mh_y_pps_018}
\item \code{mh_y_pps_019}
\item \code{mh_y_pps_020}
\item \code{mh_y_pps_021}
}
}
}
\examples{
\dontrun{
compute_mh_y_pps_nm(data) |>
  select(
    any_of(c("mh_y_pps_nm", vars_mh_y_pps_count))
  )
}
}
\seealso{
\code{\link[=compute_mh_y_pps_count]{compute_mh_y_pps_count()}}
}
