% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_su.R
\docType{data}
\name{vars_su_y_caff__energy__drink}
\alias{vars_su_y_caff__energy__drink}
\alias{compute_su_y_caff__energy__drink_sum}
\title{Compute "Caffeine Use Questionnaire [Youth] (Energy drink):
Sum [Validation: None]"}
\format{
vars_su_y_caff__energy__drink is a character vector
of all column names used to compute \code{compute_su_y_caff__energy__drink_sum}.
}
\usage{
vars_su_y_caff__energy__drink

compute_su_y_caff__energy__drink_sum(
  data,
  name = "su_y_caff__energy__drink_sum",
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the new column to be created (Default:
the name used in the ABCD data release).}

\item{combine}{logical. If TRUE, the new column will be bound to the input
data frame. If FALSE, the new column will be created as a new data frame.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{su_y_caff__energy__drink_sum}
Caffeine Use Questionnaire [Youth] (Energy drink):
Sum [Validation: None]
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{su_y_caff__energy__drink_001__01__01}
\item \code{su_y_caff__energy__drink_001__01__02}
\item \code{su_y_caff__energy__drink_001__01__03}
\item \code{su_y_caff__energy__drink_001__02__01}
\item \code{su_y_caff__energy__drink_001__02__02}
\item \code{su_y_caff__energy__drink_001__02__03}
\item \code{su_y_caff__energy__drink_001__03__01}
\item \code{su_y_caff__energy__drink_001__03__02}
\item \code{su_y_caff__energy__drink_001__03__03}
\item \code{su_y_caff__energy__drink_001__04__01}
\item \code{su_y_caff__energy__drink_001__04__02}
\item \code{su_y_caff__energy__drink_001__04__03}
}
\item \emph{Excluded values:} none
\item \emph{Validation criterion:} none
}
}
\keyword{datasets}
