% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_ph.R
\docType{data}
\name{vars_ph_p_otbi__loc_count}
\alias{vars_ph_p_otbi__loc_count}
\alias{compute_ph_p_otbi__loc_count}
\title{Compute "Ohio State Traumatic Brain Injury Screen [Parent] (Loss of
consciousness): Count"}
\format{
vars_ph_p_otbi__loc_count is a character vector of all column names
used to compute summary score of \code{ph_p_otbi__loc_count}.
}
\usage{
vars_ph_p_otbi__loc_count

compute_ph_p_otbi__loc_count(
  data,
  name = "ph_p_otbi__loc_count",
  exclude = c("777", "999"),
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score column.}

\item{exclude}{character vector. Values to be excluded from the summary
score calculation.}

\item{combine}{logical. If \code{TRUE} (default), the summary score is
is appended as a new column to the input data frame. If \code{FALSE}, the
summary score is returned as a separate one-column data frame.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{ph_p_otbi__loc_count}
Ohio State Traumatic Brain Injury Screen [Parent] (Loss of
consciousness): Count
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{ph_p_otbi_001}
\item \code{ph_p_otbi__loc_001}
\item \code{ph_p_otbi_002}
\item \code{ph_p_otbi__loc_002}
\item \code{ph_p_otbi_003}
\item \code{ph_p_otbi__loc_003}
\item \code{ph_p_otbi_004}
\item \code{ph_p_otbi__loc_004}
\item \code{ph_p_otbi_005}
\item \code{ph_p_otbi__loc_005}
\item \code{ph_p_otbi__loc__add_001}
\item \code{ph_p_otbi__loc__add_001__01}
\item \code{ph_p_otbi__rpt_001}
\item \code{ph_p_otbi__rpt__loc_001}
\item \code{ph_p_otbi__rpt_002}
\item \code{ph_p_otbi__rpt__loc__daz_002}
\item \code{ph_p_otbi__rpt_003}
\item \code{ph_p_otbi__rpt__loc__daz_003}
\item \code{ph_p_otbi_001__l}
\item \code{ph_p_otbi__loc_001__l}
\item \code{ph_p_otbi_002__l}
\item \code{ph_p_otbi__loc_002__l}
\item \code{ph_p_otbi_003__l}
\item \code{ph_p_otbi__loc_003__l}
\item \code{ph_p_otbi_004__l}
\item \code{ph_p_otbi__loc_004__l}
\item \code{ph_p_otbi_005__l}
\item \code{ph_p_otbi__loc_005__l}
\item \code{ph_p_otbi__loc__add_001__l}
\item \code{ph_p_otbi__loc__add_001__01__l}
\item \code{ph_p_otbi__rpt_001__l}
\item \code{ph_p_otbi__rpt__loc_001__l}
}
\item \emph{Excluded values:}
\itemize{
\item 777
\item 999
}
}
}
\keyword{datasets}
