% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_ab.R
\docType{data}
\name{vars_ab_g_dyn__cohort_edu__cgs}
\alias{vars_ab_g_dyn__cohort_edu__cgs}
\alias{compute_ab_g_dyn__cohort_edu__cgs}
\title{Compute "Cohort description: Highest education across caregivers"}
\format{
a character vector
of all column names used to compute summary score of
\code{ab_g_dyn__cohort_edu__cgs}.
}
\usage{
vars_ab_g_dyn__cohort_edu__cgs

compute_ab_g_dyn__cohort_edu__cgs(
  data,
  name = "ab_g_dyn__cohort_edu__cgs",
  exclude = c("777", "999"),
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character, Name of the new column to be created. Default is
the name in description, but users can change it.}

\item{exclude}{character vector. Values to be excluded from the summary
score calculation.}

\item{combine}{logical, If \code{TRUE}, the summary score will be appended to
the input data frame. If \code{FALSE}, the summary score for each participant
will be returned as a separate data frame. (Default: FALSE)}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{ab_g_dyn__cohort_edu__cgs}
Cohort description: Highest education across caregivers
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{ab_p_demo__edu__slf_001}
\item \code{ab_p_demo__edu__slf_001__v01}
\item \code{ab_p_demo__edu__slf_001__v02}
\item \code{ab_p_demo__edu__prtnr_001}
\item \code{ab_p_demo__edu__prtnr_001__v01}
}
\item \emph{Excluded values:}
\itemize{
\item 777
\item 999
}
}
}
\keyword{datasets}
