% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh_aseba.R
\name{compute_mh_y_ysr__synd__aggr_sum}
\alias{compute_mh_y_ysr__synd__aggr_sum}
\title{Compute "Youth Self Report [Youth] (Syndrome Scale - Aggressive behavior):
Sum"}
\usage{
compute_mh_y_ysr__synd__aggr_sum(
  data,
  name = "mh_y_ysr__synd__aggr_sum",
  max_na = 3,
  exclude = c("777", "999"),
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score column.}

\item{max_na}{numeric, positive whole number. Number of missing items
allowed. \code{NULL} means no limit.}

\item{exclude}{character vector. Values to be excluded from the summary score.}

\item{combine}{logical. If \code{TRUE} (default), the summary score is
is appended as a new column to the input data frame. If \code{FALSE}, the
summary score is returned as a separate one-column data frame.}
}
\value{
tbl. see \code{combine}.
}
\description{
Computes the summary score \code{mh_y_ysr__synd__aggr_sum}
Youth Self Report [Youth] (Syndrome Scale - Aggressive behavior): Sum
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{mh_y_ysr__aggr__opp_001}
\item \code{mh_y_ysr__aggr__cond_001}
\item \code{mh_y_ysr__aggr_001}
\item \code{mh_y_ysr__aggr_002}
\item \code{mh_y_ysr__aggr__cond_002}
\item \code{mh_y_ysr__aggr__opp_002}
\item \code{mh_y_ysr__aggr__opp_003}
\item \code{mh_y_ysr__aggr__cond_003}
\item \code{mh_y_ysr__aggr__cond_004}
\item \code{mh_y_ysr__aggr_003}
\item \code{mh_y_ysr__aggr__opp_004}
\item \code{mh_y_ysr__aggr_004}
\item \code{mh_y_ysr__aggr_005}
\item \code{mh_y_ysr__aggr_006}
\item \code{mh_y_ysr__aggr__opp_005}
\item \code{mh_y_ysr__aggr__cond_005}
\item \code{mh_y_ysr__aggr__adhd_001}
}
\item \emph{Excluded values:}
\itemize{
\item 777
\item 999
}
\item \emph{Validation criterion:} maximally 3 of 17 items missing
}
}
\examples{
\dontrun{
compute_mh_y_ysr__synd__aggr_sum(data) |>
  select(
    any_of(c("mh_y_ysr__synd__aggr_sum", vars_mh_y_ysr__synd__aggr))
  )
}
}
\seealso{
\code{\link[=compute_mh_y_ysr__synd__aggr_nm]{compute_mh_y_ysr__synd__aggr_nm()}}
}
