% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_fc.R
\name{compute_fc_y_pnh_all}
\alias{compute_fc_y_pnh_all}
\title{Compute all the fc_y_pnh summary scores}
\usage{
compute_fc_y_pnh_all(data)
}
\arguments{
\item{data}{tbl, Dataframe containing the columns to be summarized.}
}
\value{
tbl. The input data frame with the summary scores appended as
new columns.
}
\description{
This is a high-level function that computes all summary scores in this table.
Make sure the \code{data} contains all the necessary columns.
}
\examples{
\dontrun{
compute_fc_y_pnh_all(data)
}
}
