% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_mh.R
\name{compute_mh_y_ppsss_all}
\alias{compute_mh_y_ppsss_all}
\title{Compute all the mh_y_ppsss scores}
\usage{
compute_mh_y_ppsss_all(data)
}
\arguments{
\item{data}{tbl, Dataframe containing the columns to be summarized.}
}
\value{
a tibble of the \code{participant_id} column and the new static columns
}
\description{
A single function to compute all scores in the above domain using
\strong{default} arguments.
}
