% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_su.R
\docType{data}
\name{vars_su_y_nicsre__chew}
\alias{vars_su_y_nicsre__chew}
\alias{compute_su_y_nicsre__chew_sum}
\title{Compute "Nicotine Subjective Response and Effects [Youth] (Intensity of
positive and negative effects of first smokeless tobacco or chew use): Sum -
Negative score inverted [Validation: None missing or declined]"}
\format{
vars_su_y_nicsre__chew is a character vector of
all column names used to compute summary scores of
\code{compute_su_y_nicsre__chew} (\verb{_sum}, \verb{_nm}).
}
\usage{
vars_su_y_nicsre__chew

compute_su_y_nicsre__chew_sum(
  data,
  name = "su_y_nicsre__chew_sum",
  combine = TRUE,
  max_na = 0
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the new column to be created (Default:
the name used in the ABCD data release).}

\item{combine}{logical. If TRUE, the new column will be bound to the input
data frame. If FALSE, the new column will be created as a new data frame.}

\item{max_na}{numeric, positive whole number. Number of missing items
allowed (Default: 0).}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{su_y_nicsre__chew_sum}
Nicotine Subjective Response and Effects [Youth] (Intensity of
positive and negative effects of first smokeless tobacco or chew use): Sum -
Negative score inverted [Validation: None missing or declined]
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{su_y_nicsre__chew__pos_001}
\item \code{su_y_nicsre__chew__neg_001}
}
\item \emph{Excluded values:} none
\item \emph{Validation criterion:} maximally 0 of 2 items missing
}
}
\keyword{datasets}
