% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scores_fc.R
\docType{data}
\name{vars_fc_p_vs__ref}
\alias{vars_fc_p_vs__ref}
\alias{compute_fc_p_vs__ref_mean}
\title{Compute "Values Scale [Parent] (Family as
referent): Mean"}
\format{
vars_fc_p_vs__ref is a character vector of all column names
used to compute summary score of \code{fc_p_vs__ref}.
}
\usage{
vars_fc_p_vs__ref

compute_fc_p_vs__ref_mean(
  data,
  name = "fc_p_vs__ref_mean",
  max_na = 1,
  exclude = c("777", "999"),
  combine = TRUE
)
}
\arguments{
\item{data}{tbl. Data frame containing the columns to be summarized.}

\item{name}{character. Name of the summary score. Default is the name in
the description.}

\item{max_na}{numeric, positive whole number. Number of missing items
allowed (Default: 1).}

\item{exclude}{character vector. Values to be excluded from the summary
score calculation.}

\item{combine}{logical. If \code{TRUE}, the summary score is appended to the
input data frame. If \code{FALSE}, the summary score is returned as a separate
data frame. Default is \code{TRUE}.}
}
\value{
tbl. The input data frame with the summary score appended as
a new column.
}
\description{
Computes the summary score \code{fc_p_vs__ref_mean}
(Values Scale [Parent] (Family as referent): Mean)
\itemize{
\item \emph{Summarized variables:}
\itemize{
\item \code{fc_p_vs__ref_001}
\item \code{fc_p_vs__ref_002}
\item \code{fc_p_vs__ref_003}
\item \code{fc_p_vs__ref_004}
\item \code{fc_p_vs__ref_005}
}
\item \emph{Excluded values:}
\itemize{
\item 777
\item 999
}
\item \emph{Validation criterion:} maximally 1 of 5 items missing
}
}
\keyword{datasets}
